c **********************************************************************
c *   Converts binary format into GMT format                           *
c *                                                                    *
c *   Input parameters:                                                *
c *     f_name        : File name               (Element_Run.Restart)  *
c *                   : For example, u___01.01                         *
c *     irec          : Record number to be extracted                  *
c *     iplane        : X grid number of the vertical plane            *
c *                   : If nonpositive, not y-z plane                  *
c *     jplane        : Y grid number of the vertical plane            *
c *                   : If nonpositive, not x-z plane                  *
c *     kplane        : Z grid number of the horizontal plane          *
c *                   : If nonpositive, not x-y plane                  *
c *     inc           : Increments for x, y and z grid numbers         *
c *                   : If nonpositive, auto set according to (nx,ny)  *
c *     ival          : = 0,       raw values;                         *
c *                   : otherwise, fluctuations from horizontal ave    *
c *                                                                    *
c *                                   Dec/2009  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "../post/sub_data_dir.f"
c
      parameter ( mx=502, my=502, mz=201 )
c
      character (len=9) :: f_name
      double precision  dat(mx,mz,my), ave
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      namelist  /figs/ f_name, irec, iplane, jplane, kplane, inc, ival
c
      f_name   = ''
      irec     = 1
      iplane   = 0
      jplane   = 0
      kplane   = 0
      inc      = 1
      ival     = 0
c
      read (5,nml=figs)
c
      open (10,file='para'//f_name(5:9),status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
c
      call sub_data_open ( f_name(5:9),f_name(1:4), 11, lx,lz,ly )
c
      call sub_data_input ( 11,irec, mx,mz,my, lx,lz,ly, dat )
c
  100 close(10)
      close(11)
c
      if ( inc .le. 0 ) inc = max(max(nx,ny)/50,1)
c
      ax = 0.0
      ay = 0.0
      az = 0.0
      tx = 0.0
      ty = 0.0
      tz = 0.0
c
c  **  Velocity components are averaged to draw arrows  **
      select case ( f_name(1:3) )
        case ( 'u__'        ); ax = 0.5
        case ( 'v__'        ); ay = 0.5
        case ( 'w__'        ); az = 0.5
        case ( 'zwt', 'zwq' ); tz = 0.5
        case ( 'zwu', 'zy_' ); tz = 0.5; tx = 0.5
        case ( 'zwv', 'zx_' ); tz = 0.5; ty = 0.5
        case ( 'zz_'        ); tx = 0.5; ty = 0.5
      end select
c
      if ( ival .ne. 0 ) then
        do k = 1,nz
          ave = 0.0
          do j = 2,ny-1
          do i = 2,nx-1
            ave = ave +dat(i,k,j)
          end do
          end do
          ave = ave/dble((nx-2)*(ny-2))
c
          do j = 1,ny
          do i = 1,nx
            dat(i,k,j) = dat(i,k,j) -ave
          end do
          end do
        end do
      end if
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
      xp   = dx*( iplane-1.5-tx ); if ( xp .lt. 0.0 ) xp = dx*( nx-2 )
      yp   = dy*( jplane-1.5-ty ); if ( yp .lt. 0.0 ) yp = dy*( ny-2 )
      zp   = dz*( kplane-0.5-tz ); if ( zp .lt. 0.0 ) zp = dz*( nz   )
c
      write(6,'(i5.4)') ih
      write(6,*) dx, dy, dz
      write(6,*) xp, yp, zp
c
      if     ( iplane .gt. 0 .and. iplane .lt. nx ) then
        write(6,*) 'y-z'
c
        i = iplane
        do k = 1,nz,inc
        do j = 1,ny,inc
          plane = value ( mx, mz, nx, nz, ny, dat,
     :                    ax, ay, az, i, j, k )
          write(6,*) dy*(j-1.5-ty), dz*(k-0.5-tz), plane, j, k
        end do
        end do
c
      elseif ( jplane .gt. 0 .and. jplane .lt. ny ) then
        write(6,*) 'x-z'
c
        j = jplane
        do k = 1,nz,inc
        do i = 1,nx,inc
          plane = value ( mx, mz, nx, nz, ny, dat,
     :                    ax, ay, az, i, j, k )
          write(6,*) dx*(i-1.5-tx), dz*(k-0.5-tz), plane, i, k
        end do
        end do
c
      elseif ( kplane .gt. 0 .and. kplane .le. nz ) then
        write(6,*) 'x-y'
c
        k = kplane
        do j = 1,ny,inc
        do i = 1,nx,inc
          plane = value ( mx, mz, nx, nz, ny, dat,
     :                    ax, ay, az, i, j, k )
          write(6,*) dx*(i-1.5-tx), dy*(j-1.5-ty), plane, i, j
        end do
        end do
      end if
c
      stop
      end
c
      function  value ( mx, mz, nx, nz, ny, dat,
     :                  ax, ay, az, i, j, k )
c
      double precision  dat(mx,mz,ny)
c
      bx  = 1.0 -ax
      by  = 1.0 -ay
      bz  = 1.0 -az
      ip1 = i +1; if ( ip1 .gt. nx ) ip1 = 3
      jp1 = j +1; if ( jp1 .gt. ny ) jp1 = 3
c
      value = ax*ay*az * dat(ip1,k+1,jp1)
     :      + ax*ay*bz * dat(ip1,k  ,jp1)
     :      + ax*by*az * dat(ip1,k+1,j  )
     :      + ax*by*bz * dat(ip1,k  ,j  )
     :      + bx*ay*az * dat(i  ,k+1,jp1)
     :      + bx*ay*bz * dat(i  ,k  ,jp1)
     :      + bx*by*az * dat(i  ,k+1,j  )
     :      + bx*by*bz * dat(i  ,k  ,j  )
c
      return
      end
