#!/bin/sh

. ./GetOpts

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

F_NAME=${Q_IN}${N_IN}
$SDIR/bin2txt << EOF1 > $GDIR/$F_OUT.ddt
&figs
f_name = $F_NAME
irec   = $IREC
kplane = $KPLANE
ival   = $IVAL
/
EOF1

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.ddt`
DX=`awk 'NR == 2 {print $1}' $F_OUT.ddt`
DY=`awk 'NR == 2 {print $2}' $F_OUT.ddt`
DZ=`awk 'NR == 2 {print $3}' $F_OUT.ddt`
XP=`awk 'NR == 3 {print $1}' $F_OUT.ddt`
YP=`awk 'NR == 3 {print $2}' $F_OUT.ddt`
ZP=`awk 'NR == 3 {print $3}' $F_OUT.ddt`
PLANE=`awk 'NR == 4 {print $1}' $F_OUT.ddt`

. $SDIR/SetAxes

###  m -> km
XDISB=`echo "scale=2; $XDIS/1000" | bc`
YDISB=`echo "scale=2; $YDIS/1000" | bc`
###
if [ `echo "$XDIS/$XINC" | bc` -ge 500 ]; then
  XINC2=$XINC
  YINC2=$YINC
else
  XINC2=`echo "scale=2; $XDIS/500" | bc`
  YINC2=$XINC2
fi

TITLE1="$F_NAME"
TITLE2="$PLOT m at $TIME"
XLEN=12
YLEN=`echo "scale=2; $XLEN*$YDIS/$XDIS" | bc`
YPOS=`echo "scale=2; $YLEN+0.3" | bc`

if [ `echo $XDIS | cut -d'.' -f1` -lt 15000 ]; then
  XTICK="a1f0.1"
else
  XTICK="a2f0.2"
fi

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.1c
gmtset TICK_LENGTH     -0.2c

### Color palette
if [ -n "$COLOR" ]; then
  CMIN=`echo "scale=5; (-5.0)*$CDEL" | bc`
  CMAX=`echo "scale=5;  (5.0)*$CDEL" | bc`
  makecpt -Cno_green -T$CMIN/$CMAX/$CDEL > $F_OUT.cpt
else
  CMIN=`echo "scale=5; (-4.0)*$CDEL" | bc`
  CMAX=`echo "scale=5;  (4.0)*$CDEL" | bc`
  makecpt -Cgray -T$CMIN/$CMAX/$CDEL > $F_OUT.cpt
fi

###
awk -v fact=$FACT 'NR > 4 {print $1, $2, $3*fact}' $F_OUT.ddt | \
surface -T0.25 -R0/$XDIS/0/$YDIS -I$XINC2/$YINC2 -G$F_OUT.grd
grdimage $F_OUT.grd -C$F_OUT.cpt -JX$XLEN/$YLEN -P -X3.0 -Y4.0 -K > $F_OUT.ps

if [ -z "$COLOR" ]; then
  CCON=`echo "scale=5;  (3.0)*$CDEL" | bc`
  grdcontour $F_OUT.grd -C$CCON -JX -W1 -K -O >> $F_OUT.ps
fi

### Base map
psbasemap -JX -R0/$XDISB/0/$YDISB -B"$XTICK":"$XLAB":/"$XTICK":"$YLAB":WeSn -K -O >> $F_OUT.ps

### Title & Color scale
echo 0.5 $YPOS 14 0 0 LB "$TITLE1" | \
pstext -JX -R0/$XLEN/0/$YLEN -N -K -O >> $F_OUT.ps
echo 5.0 $YPOS 12 0 0 LB "$TITLE2" | \
pstext -JX -R -N -K -O >> $F_OUT.ps

# XCEN=`echo "scale=2; $XLEN/2.0" | bc`
# XWDT=`echo "scale=2; $XLEN/1.5" | bc`
# psscale -C$F_OUT.cpt -D$XCEN/-1.5/$XWDT/0.3h -E0.8 -O >> $F_OUT.ps
XCEN=`echo "scale=2; $XLEN+0.5" | bc`
YCEN=`echo "scale=2; $YLEN/2.0" | bc`
XWDT=`echo "scale=2; $YLEN/1.2" | bc`
PDEL=a"$CDEL"g"$CDEL"
psscale -C$F_OUT.cpt -D$XCEN/$YCEN/$XWDT/0.3 -B"$PDEL"/:"$USCL": -E0.8 -O >> $F_OUT.ps

# rm -f $F_OUT.ddt
rm -f $F_OUT.cpt
rm -f $F_OUT.grd

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
