#!/bin/sh

# Displays case variations

. ./Xtick.sh

DDIR=/work2/typh
#? N_IN=("01.02" "02.02")
N_IN=("02.02" "02.02")
IREC=(60 60)
#? LINE=("W8" "W8t20_10:0")
LINE=("W10" "W5")
NLBL=("100 km" "40 km")

#? NSUM=`expr ${#IREC[@]} - 1`
NSUM=0

FACT=1000000.0
KPLANE=30

while getopts d:f:s:e:k: OPT
do
  case $OPT in
    "d") DDIR=$OPTARG   ;;
    "f") FACT=$OPTARG   ;;
    "s") XS=$OPTARG     ;;
    "e") XE=$OPTARG     ;;
    "k") KPLANE=$OPTARG ;;
     * ) exit 1         ;;
  esac
done

F_OUT=test
SDIR=$PWD/../post
GDIR=$DDIR/Movie

cd $DDIR

for N in `seq 0 $NSUM`
do
$SDIR/iner_stab << EOF1 > $GDIR/$F_OUT.dat$N
&post
r_num  = ${N_IN[$N]}
irec   = ${IREC[$N]}
kplane = $KPLANE
/
EOF1
done

cd $GDIR

DX=`awk 'NR == 2 {print $1}' $F_OUT.dat0`
XP=`awk 'NR == 3 {print $1}' $F_OUT.dat0`
ZP=`awk 'NR == 3 {print $2}' $F_OUT.dat0`

XINCB=`echo "scale=2; $DX/1000" | bc`
XDISB=`echo "scale=2; $XP/1000" | bc`

FPWR=`awk -v fact=$FACT 'BEGIN {x=log(fact)/log(10.0); if (x>0) {x=int(x+0.5)} else {x=int(x-0.5)}; print -x}'`

XLEN=8
YLEN=6
XLAB="x (km)"
YLAB=`printf "Inertial stability (10@+%d@+ s@+-2@+)" $FPWR`

xtick "$F_OUT.dat0"

XPOS=1.6

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`

if [ `echo $XP | cut -d'.' -f1` -lt 15000 ]; then
  HTICK="a2f0.2"
else
  HTICK="a5f1"
fi

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

### Base map
psbasemap -JX$XLEN/$YLEN -R0/$XDISB/$XS/$XE -B"$HTICK":"$XLAB":/"$XTICK":"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
if [ \( $XS -lt 0 -a $XE -gt 0 \) ]; then
  { echo 0 0; echo $XDISB 0; } | \
  psxy -JX -R -W2 -K -O >> $F_OUT.ps
fi

for N in `seq 0 $NSUM`
do
  TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat$N`

  YPOS=`echo "scale=2; $YLEN-1.7-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v fact=$FACT 'NR > 4 {print $2/1000.0, $1*fact}' $F_OUT.dat$N | \
  psxy -JX -R0/$XDISB/$XS/$XE -${LINE[$N]} -K -O >> $F_OUT.ps

### Legend
# echo $XPOS $YPOS 12 0 0 LM "${NLBL[$N]}" | \
# pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

# { echo $XPLS $YPLS; echo $XPLE $YPLS; } | \
# psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
done

YPOS=`echo "scale=2; $YLEN-0.7" | bc`
echo 1.0 $YPOS 12 0 0 LM "z = $ZP m at $TIME" | \
pstext -JX -R0/$XLEN/0/$YLEN -O >> $F_OUT.ps

rm -f $F_OUT.dat*

kghostview $F_OUT.ps
