#!/bin/sh

ANG=(-180 -90)
NSUM=`expr ${#ANG[@]} - 1`

DDIR=/work
N_IN="01.01"
IRSTA=1
IREND=1
XS=-0.4
XE=1.2
VIEW="TRUE"

while getopts d:n:r:R:z:x OPT
do
  case $OPT in
    "d") DDIR=$OPTARG  ;;
    "n") N_IN=$OPTARG  ;;
    "r") IRSTA=$OPTARG ;;
    "R") IREND=$OPTARG ;;
    "z") ZP=$OPTARG    ;;
    "x") VIEW=""       ;;
     * ) exit 1        ;;
  esac
done

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

F_NAME="u___"${N_IN}
$SDIR/bin2prf << EOF1 > $GDIR/$F_OUT.duc
&figs
f_name = "$F_NAME"
irec   =  $IRSTA
irend  =  $IREND
/
EOF1

F_NAME="v___"${N_IN}
$SDIR/bin2prf << EOF2 > $GDIR/$F_OUT.dvc
&figs
f_name = "$F_NAME"
irec   =  $IRSTA
irend  =  $IREND
/
EOF2

cd $GDIR

TMST=`awk 'NR == 1 {print $1}' $F_OUT.duc`
TMED=`awk 'NR == 1 {print $2}' $F_OUT.duc`
DZ=`awk 'NR == 2 {print $1}' $F_OUT.duc`
ZT=`awk 'NR == 3 {print $1}' $F_OUT.duc`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

if [ $IREND -le $IRSTA ]; then
  TITLE="Time  $TMST"
else
  TITLE="Time  $TMST-$TMED"
fi
XLEN=8
YLEN=8
YLAB="Height (km)"
XLAB='Normalized U and V'
FACT=1.0

XTICK="a0.4f0.1"

YPOS=`echo "scale=2; $YLEN-0.9" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

### Base map
psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"$XLAB":/a0.5f0.1:"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
{ echo 0 0; echo 0 $ZP; } | \
psxy -JX -R -W2 -K -O >> $F_OUT.ps
{ echo 1 0; echo 1 $ZP; } | \
psxy -JX -R -W2 -K -O >> $F_OUT.ps

for N in `seq 0 $NSUM`
do
  paste $F_OUT.duc $F_OUT.dvc | \
  awk 'NR > 4 {print}' | \
  awk -v ang=${ANG[$N]} -f $SDIR/infpnt.awk > $F_OUT.dat

### Profile
  awk '$1 != "point" {print $2, $3/1000.0}' $F_OUT.dat | \
  psxy -JX -R$XS/$XE/0/$ZP -W8 -K -O >> $F_OUT.ps

### Inflection point
  awk '$1 == "point" {print $2, $3/1000.0}' $F_OUT.dat | \
  psxy -JX -R -Sc0.25 -G0/0/0 -K -O >> $F_OUT.ps
done

### Legend
echo 0.6 $YPOS 12 0 0 LM "$TITLE" | \
pstext -JX -R0/$XLEN/0/$YLEN -W255/255/255 -C0.1 -O >> $F_OUT.ps
# pstext -JX -R0/$XLEN/0/$YLEN -W255/255/255o -C0.2 -O >> $F_OUT.ps

rm -f $F_OUT.d*

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
