#!/bin/sh

# Displays case variations

ANG=(-180 -90)
NSUM=`expr ${#ANG[@]} - 1`

DDIR=/work2/typh
N_IN=("21.02" "22.02")
IRSTA=(60 60)
# LINE=("W8" "W8t20_10:0")
LINE=("W10" "W5")
NLBL=("100 km" "40 km")

MSUM=`expr ${#IRSTA[@]} - 1`

XS=-0.4
XE=1.2

while getopts d:z: OPT
do
  case $OPT in
    "d") DDIR=$OPTARG  ;;
    "z") ZP=$OPTARG    ;;
     * ) exit 1        ;;
  esac
done

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

for M in `seq 0 $MSUM`
do
F_NAME="u___"${N_IN[$M]}
$SDIR/bin2prf << EOF1 > $GDIR/$F_OUT.duc$M
&figs
f_name = "$F_NAME"
irec   =  ${IRSTA[$M]}
irend  =  ${IRSTA[$M]}
/
EOF1

F_NAME="v___"${N_IN[$M]}
$SDIR/bin2prf << EOF2 > $GDIR/$F_OUT.dvc$M
&figs
f_name = "$F_NAME"
irec   =  ${IRSTA[$M]}
irend  =  ${IRSTA[$M]}
/
EOF2
done

cd $GDIR

ZT=`awk 'NR == 3 {print $1}' $F_OUT.duc0`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=8
YLEN=8
YLAB="Height (km)"
XLAB='Normalized U and V'
FACT=1.0

XTICK="a0.4f0.1"

XPOS=4.5

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

### Base map
psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"$XLAB":/a0.5f0.1:"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
{ echo 0 0; echo 0 $ZP; } | \
psxy -JX -R -W2 -K -O >> $F_OUT.ps
{ echo 1 0; echo 1 $ZP; } | \
psxy -JX -R -W2 -K -O >> $F_OUT.ps

for M in `seq 0 $MSUM`
do
  TMST=`awk 'NR == 1 {print $1}' $F_OUT.duc$M`

  YPOS=`echo "scale=2; $YLEN-0.9-$M*0.5" | bc`
  YPLS=$YPOS

for N in `seq 0 $NSUM`
do
  paste $F_OUT.duc$M $F_OUT.dvc$M | \
  awk 'NR > 4 {print}' | \
  awk -v ang=${ANG[$N]} -f $SDIR/infpnt.awk > $F_OUT.dat

### Profile
  awk '$1 != "point" {print $2, $3/1000.0}' $F_OUT.dat | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$M]} -K -O >> $F_OUT.ps

### Inflection point
  awk '$1 == "point" {print $2, $3/1000.0}' $F_OUT.dat | \
  psxy -JX -R -Sc0.25 -G0/0/0 -K -O >> $F_OUT.ps
done

### Legend
  echo $XPOS $YPOS 12 0 0 LM "${NLBL[$M]}" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -${LINE[$M]} -K -O >> $F_OUT.ps
done

YPOS=`echo "scale=2; $YLEN-0.9" | bc`
echo 0.6 $YPOS 12 0 0 LM "Time  $TMST" | \
pstext -JX -R -W255/255/255 -C0.1 -O >> $F_OUT.ps

# rm -f $F_OUT.d*

kghostview $F_OUT.ps
