c **********************************************************************
c *   Input of observational vertical distributions                    *
c *                                                                    *
c *   # This is adapted from src/init_in.f.                            *
c *                                                                    *
c *   Input parameters:                                                *
c *     f_name        : File name                                      *
c *     irec          : Record number to be extracted                  *
c *     iqnt          : = 'u___', U velocity component                 *
c *                   : = 'v___', V velocity component                 *
c *                   : = 'th__', Potential temperature                *
c *                   : = 'qv__', Specific humidity                    *
c *                   : = 'ws__', Wind speed                           *
c *                                                                    *
c *   Data stored in the file 'OBS':                                   *
c *     nzob          : Number of observational levels                 *
c *     tref          : Reference 'potential' temperature  (0.1deg.C)  *
c *     tsf           : Temperature at the ground surface  (0.1deg.C)  *
c *     psf           : Pressure    at the ground surface    (0.1hPa)  *
c *     hob           : Height above ground level                 (m)  *
c *     pob           : Pressure                             (0.1hPa)  *
c *     tob           : Temperature                        (0.1deg.C)  *
c *     qob           : Specific humidity                   (0.1g/kg)  *
c *     uob, vob      : Horizontal velocity components      (0.01m/s)  *
c *                                                                    *
c *   # Units of data are applied to the Integer type in ASCII file.   *
c **********************************************************************
c
      include "../src/Implicit.h"
c
      parameter ( mob=201 )
      dimension  hob(mob), pob(mob), tob(mob), qob(mob),
     :           uob(mob), vob(mob)
c
      character (len=64) :: f_name
      character (len=4)  :: iqnt
      data      rd,     cp,     p0,     t0
     :    /  287.0, 1004.0, 1000.0, 273.15/
c
      namelist  /figs/ f_name, irec, iqnt
c
      f_name   = ''
      irec     = 1
      iqnt     = 'th__'
c
      read (5,nml=figs)
c
c  ***  For ASCII file  ***
      open (12,file=f_name,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'obs-file not found.'
c
      do k = 1,irec
c
      read (12,'(i5,3f5.1,i5)',err=10)  nzob, tref, tsf, psf, itime
c
      if ( mob .lt. nzob ) goto 999
c
      read (12,'(51f5.0)')  ( hob(m),m=1,nzob )
      read (12,'(51f5.1)')  ( pob(m),m=1,nzob )
      read (12,'(51f5.1)')  ( tob(m),m=1,nzob )
      read (12,'(51f5.1)')  ( qob(m),m=1,nzob )
      read (12,'(51f5.2)')  ( uob(m),m=1,nzob )
      read (12,'(51f5.2)')  ( vob(m),m=1,nzob )
c
      end do
c
      goto 20
c
   10 close(12)
c
c  ***  For BINARY file  ***
      open (12,file=f_name,status='old',form='unformatted',iostat=ios)
      if ( ios .ne. 0 ) stop 'obs-file not found.'
c
      do k = 1,irec
c
      read (12,err=20)  nzob, tref, tsf, psf, itime
c
      if ( mob .lt. nzob ) goto 999
c
      read (12)  ( hob(m),m=1,nzob )
      read (12)  ( pob(m),m=1,nzob )
      read (12)  ( tob(m),m=1,nzob )
      read (12)  ( qob(m),m=1,nzob )
      read (12)  ( uob(m),m=1,nzob )
      read (12)  ( vob(m),m=1,nzob )
c
      end do
c
   20 continue
c
        tref   = nint( ( tref+t0 )*100.0 ) / 100.0
        tsf    = ( tsf   +t0 )*( p0/psf    )**( rd/cp )
c
      do m = 1,nzob
        tob(m) = ( tob(m)+t0 )*( p0/pob(m) )**( rd/cp )
        qob(m) =   qob(m)     *  1.0e-3
      end do
c
      close(12)
c
      write(6,'(i5.4)') itime
      write(6,*) nzob
      write(6,*) real(hob(nzob))
      write(6,*) 'observation'
c
      do m = 1,nzob
        select case ( iqnt )
          case ( 'u___' ); write(6,*) real(uob(m)), real(hob(m))
          case ( 'v___' ); write(6,*) real(vob(m)), real(hob(m))
          case ( 'th__' ); write(6,*) real(tob(m)), real(hob(m))
          case ( 'qv__' ); write(6,*) real(qob(m)), real(hob(m))
          case ( 'ws__' ); write(6,*) real(sqrt(uob(m)**2+vob(m)**2)),
     :                                              real(hob(m))
        end select
      end do
c
      stop
c
  999 stop 'mob must be larger than nzob.'
      end
