#!/bin/sh

###
# NORM=`echo "scale=5; 920/1.4918^3" | bc`
NORM=1.0
echo "zi/u*^3 = $NORM"

MODE=(2 3 10 6)
# MODE=(6 7 5 11)

# Lower and upper heights (km) of the inversion layer
HLOW=0.88
HUPP=1.24
# HLOW=0.76
# HUPP=1.08
###

. ../GetYesNo.sh

LINE=("W8" "W8t25_15:0" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "Sx0.15")
NSUM=`expr ${#LINE[@]} - 1`

# TERM=("Sc" "B" "T+P")
TERM=("Sc" "B")
XLAB=("S@-cross@-" "B" "T+P")
MSUM=`expr ${#TERM[@]} - 1`

FLBL=("(a)" "(b)" "(c)")

FACT=1000000
XE=2

. ./GetOpts

XS=`echo "scale=2; $XE*(-0.5)" | bc`

if GetYesNo "### Do you recalculate bud-data. (y/n) ?"
then
  CALC="TRUE"
else
  CALC=""
fi

F_OUT=test
SDIR=$HOME/les_for_es/pod
GDIR=$DDIR/Movie

cd $DDIR

if [ -n "$CALC" ]; then

$SDIR/pod_bud << EOF1 > $GDIR/$F_OUT.bud
&pod1
r_num = $N_IN
irsta = 1
irend = 999
kmax  = 999
/
&pod2
kx  (1,1) =  4,  4,  5,  6,  7,  7,  7,  8,  9, 11, 13,
ky  (1,1) =  0, -1,  1,  0,  0, -1,  1, -1,  0,  1,  0,
mode(1,1) =  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
/

For 21.02
kx  (1,1) =  5,  5,  6,  6,  7,  8,  8,  9, 11, 12,
ky  (1,1) =  0,  1,  0,  1,  1,  1,  2,  2,  1,  3,
mode(1,1) =  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,

For 22.02
kx  (1,1) =  4,  4,  5,  6,  7,  7,  7,  8,  9, 11, 13,
ky  (1,1) =  0, -1,  1,  0,  0, -1,  1, -1,  0,  1,  0,
mode(1,1) =  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
EOF1

fi

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.bud`
DZ=`awk 'NR == 2 {print $1}' $F_OUT.bud`
ZT=`awk 'NR == 3 {print $1}' $F_OUT.bud`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
if [ "$FACT" != "1.0" ]; then
  XADD=`printf " (10@+%d@+ m@+-1@+s@+-1@+)" $FPWR`
fi
YLAB="Height (km)"

if   [ `echo $XE | cut -d'.' -f1` -lt 2 ]; then
  XTICK="a0.5f0.5"
elif [ `echo $XE | cut -d'.' -f1` -gt 3 ]; then
  XTICK="a3f3"
else
  XTICK="a1f1"
fi

XPOS=`echo "scale=2; $XLEN-2.2" | bc`

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`
XPLM=`echo "scale=2; $XPOS-0.6" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

for M in `seq 0 $MSUM`
do

### Base map
if [ $M -eq 0 ]; then
  psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"${XLAB[$M]}$XADD":/a0.5f0.1:"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
else
  XS=-0.6
  XE=0.6
  XTICK="a0.3f0.3"

  psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"${XLAB[$M]}$XADD":/a0.5f0.1WeSn -X7.2 -K -O >> $F_OUT.ps
fi
  { echo 0 0; echo 0 $ZP; } | \
  psxy -JX -R -W2 -K -O >> $F_OUT.ps
###
  { echo $XS $HLOW; echo $XE $HLOW; } | \
  psxy -JX -R -W2t25_15:0 -K -O >> $F_OUT.ps
  { echo $XS $HUPP; echo $XE $HUPP; } | \
  psxy -JX -R -W2t25_15:0 -K -O >> $F_OUT.ps
###

  N=-1
for NUM in ${MODE[@]}
do
  N=`expr $N + 1`
  KX=`awk -v num=$NUM 'NR > 4 && $1==num && $2=="k" {print $3}' $F_OUT.bud`
  KY=`awk -v num=$NUM 'NR > 4 && $1==num && $2=="k" {print $4}' $F_OUT.bud`
  WNO=`printf "(%3d,%3d)\n" $KX $KY`
  if [ $N -gt $NSUM ]; then
    break
  fi

  YPOS=`echo "scale=2; $YLEN-0.7-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v num=$NUM -v term=${TERM[$M]} -v fact=$FACT -v norm=$NORM 'NR > 4 && $1==num && $2==term {print $3*fact*norm, $4/1000.0}' $F_OUT.bud | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$N]} -K -O >> $F_OUT.ps

### Legend
  if [ $M -eq 0 ]; then
    echo $XPOS $YPOS 12 0 0 LM "$WNO" | \
    pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

    { echo $XPLS $YPLS; echo $XPLM $YPLS; echo $XPLE $YPLS; } | \
    psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
  fi
done

  YPOS=`echo "scale=2; $YLEN-0.9" | bc`
  echo 0.6 $YPOS 14 0 0 LB "${FLBL[$M]}" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps
done

echo 0 0 | psxy -JX -R -O >> $F_OUT.ps

# rm -f $F_OUT.bud

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
