#!/bin/sh

LINE=("W8" "W8t25_15:0" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "Sc0.12")
NSUM=`expr ${#LINE[@]} - 1`

TERM=("vv" "uv" "vw")
XLAB=("<v@+2@+>" "<uv>" "<vw>")
XSTA=(0.0 -10.0 -10.0)
XEND=(50.0 10.0 10.0)
XTICK=("a20f10" "a5f1" "a5f1")
MSUM=`expr ${#TERM[@]} - 1`

FACT=1000

. ./GetOpts

F_OUT=test
SDIR=$HOME/les_for_es/pod
GDIR=$DDIR/Movie

cd $DDIR

$SDIR/pod_cov << EOF1 > $GDIR/$F_OUT.dat
&pod1
r_num = $N_IN
kmax  = 999
/
&pod2
kx  (1,1) =  4,  5,  6,  7,  8,
ky  (1,1) =  0,  0,  0,  0,  2,
mode(1,1) =  1,  1,  1,  1,  1,
/

kx  (1,1) =  9, 10, 11, 14, 20, 23,
ky  (1,1) =  2,  2,  1,  1,  2,  2,
mode(1,1) =  1,  1,  1,  1,  1,  1,
EOF1

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat`
DZ=`awk 'NR == 2 {print $1}' $F_OUT.dat`
ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
UNIT=`printf " (10@+%d@+ m@+2@+ s@+-2@+)" $FPWR`
YLAB="Height (km)"

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

for M in `seq 0 $MSUM`
do

### Base map
if [ $M -eq 0 ]; then
  XPOS=`echo "scale=2; $XLEN-2.2" | bc`

  psbasemap -JX$XLEN/$YLEN -R${XSTA[$M]}/${XEND[$M]}/0/$ZP -B"${XTICK[$M]}":"${XLAB[$M]}$UNIT":/a0.5f0.1:"$YLAB":WeSn -X3.0 -Y4.0 -K > $F_OUT.ps
else
  XPOS=1.6

  psbasemap -JX$XLEN/$YLEN -R${XSTA[$M]}/${XEND[$M]}/0/$ZP -B"${XTICK[$M]}":"${XLAB[$M]}$UNIT":/a0.5f0.1WeSn -X7.2 -K -O >> $F_OUT.ps
fi

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`
XPLM=`echo "scale=2; $XPOS-0.6" | bc`

for N in `seq 0 $NSUM`
do
  KX=`awk -v num=$N 'NR > 4 && $1==num+1 && $2=="k" {print $3}' $F_OUT.dat`
  KY=`awk -v num=$N 'NR > 4 && $1==num+1 && $2=="k" {print $4}' $F_OUT.dat`
  WNO=`printf "(%3d,%3d)\n" $KX $KY`
  if [ -z $KX ]; then
    break
  fi

  YPOS=`echo "scale=2; $YLEN-0.7-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v num=$N -v term=${TERM[$M]} -v fact=$FACT 'NR > 4 && $1==num+1 && $2==term {print $3*fact, $4/1000.0}' $F_OUT.dat | \
  psxy -JX -R${XSTA[$M]}/${XEND[$M]}/0/$ZP -${LINE[$N]} -K -O >> $F_OUT.ps

### Legend
  echo $XPOS $YPOS 12 0 0 LM "$WNO" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLM $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
done

done

echo 0 0 | psxy -JX -R -O >> $F_OUT.ps

rm -f $F_OUT.dat

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
