#!/bin/sh

LINE=("W8" "W8t25_15:0" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "W2 -Sx0.15")
NSUM=`expr ${#LINE[@]} - 1`

TERM=("u" "v" "w")
XLAB=("|@~f@~@-u@-|" "|@~f@~@-v@-|" "|@~f@~@-w@-|")
XAXIS=(0.03 0.07 0.02)
XTICK=("a0.01f0.01" "a0.02f0.01" "a0.01f0.01")
MSUM=`expr ${#TERM[@]} - 1`

FLBL=("(a)" "(b)" "(c)")

. ./GetOpts

F_OUT=test
SDIR=$HOME/les_for_es/pod
GDIR=$DDIR/Movie

cd $DDIR

$SDIR/pod_eif << EOF1 > $GDIR/$F_OUT.dat
&pod1
r_num = $N_IN
kmax  = 999
/
&pod2
kx  (1,1) =  5,  5,  6,  6,  7,  8,
ky  (1,1) =  0,  1,  0,  1,  1,  1,
mode(1,1) =  1,  1,  1,  1,  1,  1,
/

For 21.02
kx  (1,1) =  5,  5,  6,  6,  7,  8,
ky  (1,1) =  0,  1,  0,  1,  1,  1,
mode(1,1) =  1,  1,  1,  1,  1,  1,
kx  (1,1) =  8,  9, 11, 12,
ky  (1,1) =  2,  2,  1,  3,
mode(1,1) =  1,  1,  1,  1,

For 22.02
kx  (1,1) =  4,  5,  6,  7,
ky  (1,1) =  0,  1,  0, -1,
mode(1,1) =  1,  1,  1,  1,
kx  (1,1) =  7,  8,  7,  9,
ky  (1,1) =  0, -1,  1,  0,
mode(1,1) =  1,  1,  1,  1,
kx  (1,1) = 11, 13,
ky  (1,1) =  1,  0,
mode(1,1) =  1,  1,
EOF1

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat`
DZ=`awk 'NR == 2 {print $1}' $F_OUT.dat`
ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
YLAB="Height (km)"
FACT=1

XPOS=`echo "scale=2; $XLEN-2.2" | bc`

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`
XPLM=`echo "scale=2; $XPOS-0.6" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

for M in `seq 0 $MSUM`
do

### Base map
if [ $M -eq 0 ]; then
  psbasemap -JX$XLEN/$YLEN -R0/${XAXIS[$M]}/0/$ZP -B"${XTICK[$M]}":"${XLAB[$M]}":/a0.5f0.1:"$YLAB":WeSn -X3.0 -Y4.0 -K > $F_OUT.ps
else
  psbasemap -JX$XLEN/$YLEN -R0/${XAXIS[$M]}/0/$ZP -B"${XTICK[$M]}":"${XLAB[$M]}":/a0.5f0.1WeSn -X7.2 -K -O >> $F_OUT.ps
fi

for N in `seq 0 $NSUM`
do
  KX=`awk -v num=$N 'NR > 4 && $1==num+1 && $2=="k" {print $3}' $F_OUT.dat`
  KY=`awk -v num=$N 'NR > 4 && $1==num+1 && $2=="k" {print $4}' $F_OUT.dat`
  WNO=`printf "(%3d,%3d)\n" $KX $KY`
  if [ -z $KX ]; then
    break
  fi
###
  LINEN=${LINE[$N]}
  if [ $KX -eq 1 -a $KY -eq 0 ]; then
    LINEN="Sx0.12"
  fi
###

  YPOS=`echo "scale=2; $YLEN-0.7-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v num=$N -v term=${TERM[$M]} 'NR > 4 && $1==num+1 && $2==term {print $3, $4/1000.0}' $F_OUT.dat | \
  psxy -JX -R0/${XAXIS[$M]}/0/$ZP -$LINEN -K -O >> $F_OUT.ps

### Legend
  echo $XPOS $YPOS 12 0 0 LM "$WNO" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLM $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -$LINEN -K -O >> $F_OUT.ps
done

  YPOS=`echo "scale=2; $YLEN-0.9" | bc`
  echo 1.5 $YPOS 14 0 0 LB "${FLBL[$M]}" | \
  pstext -JX -R -W255/255/255 -C0.1 -K -O >> $F_OUT.ps
done

echo 0 0 | psxy -JX -R -O >> $F_OUT.ps

rm -f $F_OUT.dat

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
