#!/bin/sh

CDEL=2.0
FACT=100.0
PART=4
WSPD=0.04

. ./GetOpts

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

F_NAME="pav_"$N_IN
$SDIR/bin2txt << EOF1 > $GDIR/$F_OUT.dvc
&figs
f_name = $F_NAME
irec   = $IREC
kplane = $KPLANE
inc    = -1
ival   = 1
/
EOF1

F_NAME="pau_"$N_IN
$SDIR/bin2txt << EOF3 > $GDIR/$F_OUT.duc
&figs
f_name = $F_NAME
irec   = $IREC
kplane = $KPLANE
inc    = -1
ival   = 1
/
EOF3

F_NAME="paw_"$N_IN
$SDIR/bin2txt << EOF4 > $GDIR/$F_OUT.dwc
&figs
f_name = $F_NAME
irec   = $IREC
kplane = $KPLANE
inc    = -1
ival   = 1
/
EOF4

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.dvc`
DX=`awk 'NR == 2 {print $1}' $F_OUT.dvc`
DY=`awk 'NR == 2 {print $2}' $F_OUT.dvc`
DZ=`awk 'NR == 2 {print $3}' $F_OUT.dvc`
XP=`awk 'NR == 3 {print $1}' $F_OUT.dvc`
YP=`awk 'NR == 3 {print $2}' $F_OUT.dvc`
ZT=`awk 'NR == 3 {print $3}' $F_OUT.dvc`
ZP=${ZP:=$ZT}
PLANE=`awk 'NR == 4 {print $1}' $F_OUT.dvc`

. $SDIR/SetAxes

if   [ "$PLANE" = "y-z" ]; then
  WIND="u@-cross@- and (u@-along@-, w)"
elif [ "$PLANE" = "x-z" ]; then
  WIND="u@-along@- and (u@-cross@-, w)"
else
  WIND="w and (u, v)"
fi

###  m -> km
XDISB=`echo "scale=2; $XDIS/1000" | bc`
YDISB=`echo "scale=2; $YDIS/1000" | bc`
###
if [ `echo "$XDIS/$XINC" | bc` -ge 500 ]; then
  XINC2=$XINC
  YINC2=$YINC
else
  XINC2=`echo "scale=2; $XDIS/500" | bc`
  YINC2=$XINC2
fi

TITLE1="$WIND"
TITLE2="$PLOT m"
XLEN=12
YLEN=`echo "scale=2; $XLEN*$YDIS/$XDIS" | bc`
YPOS=`echo "scale=2; $YLEN+0.3" | bc`

VFAC=`echo "scale=5; 0.5/$WSPD" | bc`
WPAR=0.03/0.21/0.07n0.14

FPWR=`echo "scale=0; l($FACT)/l(10.0)*(-1)" | bc -l`
UNIT=`printf "10@+%d@+ m s@+-1@+" $FPWR`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.1c
gmtset TICK_LENGTH     -0.2c

### Color palette
CMIN=`echo "scale=5; (-5.0)*$CDEL" | bc`
CMAX=`echo "scale=5;  (5.0)*$CDEL" | bc`
makecpt -Cno_green -T$CMIN/$CMAX/$CDEL > $F_OUT.cpt

### Wind velocity
awk -v fact=$FACT 'NR > 4 {print $1, $2, $3*fact}' $F_OUT.dwc | \
surface -T0.25 -R0/$XDIS/0/$YDIS -I$XINC2/$YINC2 -G$F_OUT.grd
grdimage $F_OUT.grd -C$F_OUT.cpt -JX$XLEN/$YLEN -P -X3.0 -Y4.0 -K > $F_OUT.ps

### Wind vector
paste $F_OUT.duc $F_OUT.dvc | \
awk -v vfac=$VFAC 'NR > 4 {print $1, $2, $3*vfac, $8*vfac}' | \
awk -f $SDIR/uv2ds.awk | \
psxy -JX -R -SV"$WPAR" -G0/0/0 -K -O >> $F_OUT.ps

### Base map
psbasemap -JX -R0/$XDISB/0/$YDISB -Ba1f0.1:"$XLAB":/a1f0.1:"$YLAB":WeSn -K -O >> $F_OUT.ps

### Title & Color scale
if [ -n "$LEGN" ]; then
  echo 9.3 `echo "scale=2; $YPOS+0.15" | bc` 90 0.5 | \
  psxy -JX -R0/$XLEN/0/$YLEN -SV"$WPAR" -G0/0/0 -N -K -O >> $F_OUT.ps
  echo 10.0 $YPOS 12 0 0 LB "$WSPD m s@+-1@+" | \
  pstext -JX -R -N -K -O >> $F_OUT.ps

  XCEN=`echo "scale=2; $XLEN/2.0-1.0" | bc`
  XWDT=`echo "scale=2; $XLEN/1.5" | bc`
  psscale -C$F_OUT.cpt -D$XCEN/-1.5/$XWDT/0.3h -B/:"$UNIT": -E0.8 -K -O >> $F_OUT.ps
fi

echo 0.5 $YPOS 14 0 0 LB "$TITLE1" | \
pstext -JX -R0/$XLEN/0/$YLEN -N -K -O >> $F_OUT.ps
echo 7.0 $YPOS 12 0 0 LB "$TITLE2" | \
pstext -JX -R -N -O >> $F_OUT.ps

rm -f $F_OUT.d*
rm -f $F_OUT.cpt
rm -f $F_OUT.grd

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
