#!/bin/sh

### NORM = zi/u*^3
NORM=`echo "scale=5; 920/1.4918^3" | bc`
echo "zi/u*^3 = $NORM"
###

LINE=("W8" "W8t25_15:0" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "Sx0.12")
NSUM=`expr ${#LINE[@]} - 1`

TERM=("Sc" "Sa")
XLAB=("Normalized S@-cross@-" "Normalized S@-along@-")
MSUM=`expr ${#TERM[@]} - 1`

XE=1

. ./GetOpts

if [ $XE -le 0 ]; then
  echo "XE = $XE must be positive !"
  exit 9
fi

XS=`echo "scale=2; $XE*(-0.5)" | bc`

F_OUT=test
SDIR=$HOME/les_for_es/pod
GDIR=$DDIR/Movie

cd $DDIR

$SDIR/pod_prd << EOF1 > $GDIR/$F_OUT.dat
&pod1
r_num = $N_IN
kmax  = 999
/
&pod2
kx  (1,1) =  5,  6,  5,  6,
ky  (1,1) =  0,  0,  1,  1,
mode(1,1) =  1,  1,  1,  1,
/

For 11.02
kx  (1,1) =  5,  6,  9, 10, 12,
ky  (1,1) =  1,  1,  1,  0, -1,
mode(1,1) =  1,  1,  1,  1,  1,
kx  (1,1) = 12, 13, 14, 17, 19,
ky  (1,1) =  2,  1,  1,  2,  2,
mode(1,1) =  1,  1,  1,  1,  1,
EOF1

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat`
DZ=`awk 'NR == 2 {print $1}' $F_OUT.dat`
ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
if [ "$FACT" != "1.0" ]; then
  XADD=`printf " (x10@+%d@+)" $FPWR`
fi
YLAB="Height (km)"

if [ $XE -lt 2 ]; then
  XTICK="a0.5f0.1"
else
  XTICK="a1f1"
fi

XPOS=`echo "scale=2; $XLEN-2.2" | bc`

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`
XPLM=`echo "scale=2; $XPOS-0.6" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

for M in `seq 0 $MSUM`
do

### Base map
if [ $M -eq 0 ]; then
  psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"${XLAB[$M]}$XADD":/a0.5f0.1:"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
else
  psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"${XLAB[$M]}$XADD":/a0.5f0.1WeSn -X7.2 -K -O >> $F_OUT.ps
fi
{ echo 0 0; echo 0 $ZP; } | \
psxy -JX -R -W2 -K -O >> $F_OUT.ps

for N in `seq 0 $NSUM`
do
  KX=`awk -v num=$N 'NR > 4 && $1==num+1 && $2=="k" {print $3}' $F_OUT.dat`
  KY=`awk -v num=$N 'NR > 4 && $1==num+1 && $2=="k" {print $4}' $F_OUT.dat`
  WNO=`printf "(%3d,%3d)\n" $KX $KY`
  if [ -z $KX ]; then
    break
  fi

  YPOS=`echo "scale=2; $YLEN-0.9-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v num=$N -v term=${TERM[$M]} -v fact=$FACT -v norm=$NORM 'NR > 4 && $1==num+1 && $2==term {print $3*fact*norm, $4/1000.0}' $F_OUT.dat | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$N]} -K -O >> $F_OUT.ps

### Legend
  echo $XPOS $YPOS 12 0 0 LM "$WNO" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLM $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
done

# YPOS=`echo "scale=2; $YLEN-0.9" | bc`
# echo 1.5 $YPOS 14 0 0 LB "${FLBL[$M]}" | \
# pstext -JX -R -K -O >> $F_OUT.ps
done

echo 0 0 | psxy -JX -R -O >> $F_OUT.ps

rm -f $F_OUT.dat

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
