#!/bin/sh

TERM=("Su" "Tu" "Du" "Ru" "Cu"  "Sv" "Tv" "Dv" "Rv" "Cv"  "B" "Tw+P" "Dw" "Rw" "X")
LINE=("W8" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "W2 -Sc0.12"\
      "W8" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "W2 -Sc0.12"\
      "W8t25_15:0" "W8t10_15:0" "W8t30_10_10_10:0" "W8t30_10_10_10_10_10:0" "")
NSUM=`expr ${#TERM[@]} / 3 - 1`
MSUM=$NSUM

FLBL=("(a)" "(b)" "(c)")

XE=1

. ./GetOpts

if [ $XE -le 0 ]; then
  echo "XE = $XE must be positive !"
  exit 9
fi

XS=`echo "scale=2; $XE*(-1.0)" | bc`

F_OUT=test
SDIR=$HOME/les_for_es/post
GDIR=$DDIR/Movie

cd $DDIR

$SDIR/tke_bud3 << EOF1 > $GDIR/$F_OUT.dat
&post
r_num  = $N_IN
irec   = $IREC
ziin   = $ZIIN
/
EOF1

cd $GDIR

CENT=`awk 'BEGIN {sum=0} NR > 4 && $1=="Cu" {sum=1} END {print sum}' $F_OUT.dat`
if [ $CENT -eq 0 ]; then
  NSUM=`expr $NSUM - 1`
fi

TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat`
DZ=`awk 'NR == 2 {print $1}' $F_OUT.dat`
ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
if [ "$FACT" != "1.0" ]; then
  XADD=`printf " (x10@+%d@+)" $FPWR`
fi
XLAB=("Normalized <u@+2@+>/2 budget" "Normalized <v@+2@+>/2 budget"\
      "Normalized <w@+2@+>/2 budget")
YLAB="Height (km)"

if [ $XE -gt 1 ]; then
  XTICK="a`expr $XE / 2`f1"
else
  XTICK="a0.5f0.1"
fi

XPOS=1.6

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`
XPLM=`echo "scale=2; $XPOS-0.6" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

for M in 0 1 2
do

### Base map
if [ $M -eq 0 ]; then
  psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"${XLAB[$M]}$XADD":/a0.5f0.1:"$YLAB":WeSn -X3.0 -Y4.0 -K > $F_OUT.ps
else
  psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"${XLAB[$M]}$XADD":/a0.5f0.1WeSn -X7.2 -K -O >> $F_OUT.ps
fi
  { echo 0 0; echo 0 $ZP; } | \
  psxy -JX -R -W2 -K -O >> $F_OUT.ps
if [ `echo $ZIIN | cut -d'.' -f1` -gt 0 ]; then
  PZI=`echo "scale=3; $ZIIN/1000.0" | bc`
  { echo $XS $PZI; echo $XE $PZI; } | \
  psxy -JX -R -W2t25_15:0 -K -O >> $F_OUT.ps
fi

for N in `seq 0 $NSUM`
do
  MN=`expr $N + $M \* \( $MSUM + 1 \)`
  if [ "${TERM[$MN]}" = "X" ]; then
    continue
  fi

  YPOS=`echo "scale=2; $YLEN-1.7-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v term=${TERM[$MN]} -v fact=$FACT 'NR > 4 && $1==term {print $2*fact, $3/1000.0}' $F_OUT.dat | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$MN]} -K -O >> $F_OUT.ps

### Legend
  echo $XPOS $YPOS 12 0 0 LM "${TERM[$MN]}" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLM $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -${LINE[$MN]} -K -O >> $F_OUT.ps
done

XPO2=`echo "scale=2; $XLEN-0.6" | bc`
YPOS=`echo "scale=2; $YLEN-0.9" | bc`
  echo $XPO2 $YPOS 14 0 0 RM "${FLBL[$M]}" | \
  pstext -JX -R -K -O >> $F_OUT.ps
if [ $M -ne 2 ]; then
  echo 0.6 $YPOS 12 0 0 LM "Time  $TIME" | \
  pstext -JX -R -K -O >> $F_OUT.ps
else
  echo 0.6 $YPOS 12 0 0 LM "Time  $TIME" | \
  pstext -JX -R -O >> $F_OUT.ps
fi

done

rm -f $F_OUT.dat

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
