#!/bin/sh

TERM=("Sy" "TXy" "TZy" "Ty" "By" "Dy" "Cy")
NSUM=${#TERM[@]}

CDEL=1.0
FACT=1000.0
PART=5

. ./GetOpts

echo "### Select no. 1-$NSUM"
for N in `seq 1 $NSUM`
do
  echo "  [$N] ${TERM[$N-1]}"
done
read PNUM

if [ $PNUM -lt 1 -o $PNUM -gt $NSUM ]; then
  echo "$PNUM is an invalid number!"
  exit 1
fi

PTERM=${TERM[$PNUM-1]}

F_OUT=test
SDIR=$HOME/les_for_es/post
GDIR=$DDIR/Movie

cd $DDIR

$SDIR/vor_budy << EOF1 > $GDIR/$F_OUT.ddt
&post
r_num = $N_IN
irec  = $IREC
jplane= $JPLANE
/
EOF1

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.ddt`
DX=`awk 'NR == 2 {print $1}' $F_OUT.ddt`
DY=`awk 'NR == 2 {print $2}' $F_OUT.ddt`
DZ=`awk 'NR == 2 {print $3}' $F_OUT.ddt`
XP=`awk 'NR == 3 {print $1}' $F_OUT.ddt`
YP=`awk 'NR == 3 {print $2}' $F_OUT.ddt`
ZT=`awk 'NR == 3 {print $3}' $F_OUT.ddt`
ZP=${ZP:=$ZT}
PLANE=`awk 'NR == 4 {print $1}' $F_OUT.ddt`

. $SDIR/../gmt/SetAxes

YFAC=1

XDIS=`echo "scale=2; $XDIS/$PART" | bc`

###  m -> km
XDISB=`echo "scale=2; $XDIS/1000" | bc`
YDISB=`echo "scale=2; $YDIS/1000" | bc`
###
if [ `echo "$XDIS/$XINC" | bc` -ge 500 ]; then
  XINC2=$XINC
  YINC2=$YINC
else
  XINC2=`echo "scale=2; $XDIS/500" | bc`
  YINC2=$XINC2
fi

TITLE1="Vorticity budget ($PTERM)"
TITLE2="$PLOT m at $TIME"
XLEN=12
YLEN=`echo "scale=2; $XLEN*$YFAC*$YDIS/$XDIS" | bc`
YPOS=`echo "scale=2; $YLEN+0.3" | bc`

UNIT=`printf "10@+%d@+ s@+-2@+" $FPWR`

if [ `echo $YDIS | cut -d'.' -f1` -lt 2000 ]; then
  YTICK="a0.5f0.1"
else
  YTICK="a1f0.1"
fi

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.1c
gmtset TICK_LENGTH     -0.2c

### Color palette
if [ -n "$COLOR" ]; then
  CMIN=`echo "scale=5; (-5.0)*$CDEL" | bc`
  CMAX=`echo "scale=5;  (5.0)*$CDEL" | bc`
  makecpt -Cno_green -T$CMIN/$CMAX/$CDEL > $F_OUT.cpt
else
  CMIN=`echo "scale=5; (-6.0)*$CDEL" | bc`
  CMAX=`echo "scale=5;  (4.0)*$CDEL" | bc`
  makecpt -Cgray -T$CMIN/$CMAX/$CDEL | awk 'NR!=4 && NR!=5 && $1!="B" {print}' > $F_OUT.cpt
  echo "B	38	38	38" >> $F_OUT.cpt
fi

###
awk -v fact=$FACT -v term=$PTERM 'NR > 4 && $1==term {print $2, $3, $4*fact}' $F_OUT.ddt | \
surface -T0.25 -R0/$XDIS/0/$YDIS -I$XINC2/$YINC2 -G$F_OUT.grd
grdimage $F_OUT.grd -C$F_OUT.cpt -JX$XLEN/$YLEN -P -X3.0 -Y4.0 -K > $F_OUT.ps

### Base map
psbasemap -JX -R0/$XDISB/0/$YDISB -Ba1f0.1:"$XLAB":/"$YTICK":"$YLAB":WeSn -K -O >> $F_OUT.ps

### Title & Color scale
echo 0.5 $YPOS 14 0 0 LB "$TITLE1" | \
pstext -JX -R0/$XLEN/0/$YLEN -N -K -O >> $F_OUT.ps
echo 7.0 $YPOS 12 0 0 LB "$TITLE2" | \
pstext -JX -R -N -K -O >> $F_OUT.ps

XCEN=`echo "scale=2; $XLEN/2.0-0.7" | bc`
XWDT=`echo "scale=2; $XLEN/1.5" | bc`
psscale -C$F_OUT.cpt -D$XCEN/-1.5/$XWDT/0.3h -B/:"$UNIT": -E0.8 -O >> $F_OUT.ps

# rm -f $F_OUT.ddt
rm -f $F_OUT.cpt
rm -f $F_OUT.grd

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
