#!/bin/sh

. ./GetOpts

if [ $IPLANE -ne 0 ]; then
  JPLANE=0
fi

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

F_NAME="t___"$N_IN
$SDIR/bin2txt << EOF1 > $GDIR/$F_OUT.ddt
&figs
f_name = $F_NAME
irec   = $IREC
iplane = $IPLANE
jplane = $JPLANE
ival   = 1
/
EOF1

F_NAME="t___"$N_IN
$SDIR/bin2txt << EOF2 > $GDIR/$F_OUT.dpt
&figs
f_name = $F_NAME
irec   = $IREC
iplane = $IPLANE
jplane = $JPLANE
ival   = 0
/
EOF2

F_NAME="u___"$N_IN
$SDIR/bin2txt << EOF3 > $GDIR/$F_OUT.duc
&figs
f_name = $F_NAME
irec   = $IREC
iplane = $IPLANE
jplane = $JPLANE
inc    = 2
ival   = 1
/
EOF3

F_NAME="w___"$N_IN
$SDIR/bin2txt << EOF4 > $GDIR/$F_OUT.dwc
&figs
f_name = $F_NAME
irec   = $IREC
iplane = $IPLANE
jplane = $JPLANE
inc    = 2
ival   = 1
/
EOF4

cd $GDIR

TIME=`awk 'NR == 1 {print $1}' $F_OUT.ddt`
DX=`awk 'NR == 2 {print $1}' $F_OUT.ddt`
DY=`awk 'NR == 2 {print $2}' $F_OUT.ddt`
DZ=`awk 'NR == 2 {print $3}' $F_OUT.ddt`
XP=`awk 'NR == 3 {print $1}' $F_OUT.ddt`
YP=`awk 'NR == 3 {print $2}' $F_OUT.ddt`
ZT=`awk 'NR == 3 {print $3}' $F_OUT.ddt`
ZP=${ZP:=$ZT}
PLANE=`awk 'NR == 4 {print $1}' $F_OUT.ddt`

. $SDIR/SetAxes

YFAC=2

###  m -> km
XDISB=`echo "scale=2; $XDIS/1000" | bc`
YDISB=`echo "scale=2; $YDIS/1000" | bc`
###
if [ `echo "$XDIS/$XINC" | bc` -ge 500 ]; then
  XINC2=$XINC
  YINC2=$YINC
else
  XINC2=`echo "scale=2; $XDIS/500" | bc`
  YINC2=$XINC2
fi

TITLE1="@~q@~@-l@- and $WIND"
TITLE2="$PLOT m at $TIME LST"
XLEN=12
YLEN=`echo "scale=2; $XLEN*$YFAC*$YDIS/$XDIS" | bc`
YPOS=`echo "scale=2; $YLEN+0.3" | bc`

VFAC=`echo "scale=5; 0.5/$WSPD" | bc`
WPAR=0.03/0.21/0.07n0.14

if [ `echo $XDIS | cut -d'.' -f1` -lt 15000 ]; then
  XTICK="a1f0.1"
else
  XTICK="a2f0.2"
fi

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.1c
gmtset TICK_LENGTH     -0.2c

### Color palette
CMIN=`echo "scale=5; (-5.0)*$CDEL" | bc`
CMAX=`echo "scale=5;  (5.0)*$CDEL" | bc`
makecpt -Cno_green -T$CMIN/$CMAX/$CDEL > $F_OUT.cpt

### Temperature fluctuation
surface $F_OUT.ddt -H4 -T0.25 -R0/$XDIS/0/$YDIS -I$XINC2/$YINC2 -G$F_OUT.grd
grdimage $F_OUT.grd -C$F_OUT.cpt -JX$XLEN/$YLEN -P -X3.0 -Y4.0 -K > $F_OUT.ps

### Temperature
xyz2grd $F_OUT.dpt -H4 -F -R0/$XDIS/0/$YDIS -I$XINC/$YINC -G$F_OUT.grd
grdcontour $F_OUT.grd -C1.0 -JX$XLEN/$YLEN -W4 -K -O >> $F_OUT.ps

### Wind vector
paste $F_OUT.duc $F_OUT.dwc | \
awk -v vfac=$VFAC 'NR > 4 {print $1, $2, $3*vfac, $8*vfac}' | \
awk -f $SDIR/uv2ds.awk | \
psxy -JX -R -SV"$WPAR" -G0/0/0 -K -O >> $F_OUT.ps

### Base map
psbasemap -JX -R0/$XDISB/0/$YDISB -B"$XTICK":"$XLAB":/a1f0.1:"$YLAB":WeSn -K -O >> $F_OUT.ps

### Title & Color scale
echo 0.5 $YPOS 14 0 0 LB "$TITLE1" | \
pstext -JX -R0/$XLEN/0/$YLEN -N -K -O >> $F_OUT.ps
echo 4.0 $YPOS 12 0 0 LB "$TITLE2" | \
pstext -JX -R -N -K -O >> $F_OUT.ps
echo 9.3 `echo "scale=2; $YPOS+0.15" | bc` 90 0.5 | \
psxy -JX -R -SV"$WPAR" -G0/0/0 -N -K -O >> $F_OUT.ps
echo 10.0 $YPOS 12 0 0 LB "$WSPD m s@+-1@+" | \
pstext -JX -R -N -K -O >> $F_OUT.ps

XCEN=`echo "scale=2; $XLEN/2.0-0.5" | bc`
XWDT=`echo "scale=2; $XLEN/1.5" | bc`
psscale -C$F_OUT.cpt -D$XCEN/-1.5/$XWDT/0.3h -B/:"K": -E0.8 -O >> $F_OUT.ps

rm -f $F_OUT.d*
rm -f $F_OUT.cpt
rm -f $F_OUT.grd

if [ -n "$VIEW" ]; then
  kghostview $F_OUT.ps
fi
