#!/bin/sh

# Displays case variations

. ./Xtick.sh

DDIR=/work2/typh
N_IN=("21.02" "22.02")
IREC=(60 60)
# LINE=("W8" "W8t20_10:0")
LINE=("W10" "W5")
NLBL=("100 km" "40 km")

NSUM=`expr ${#IREC[@]} - 1`

Q_IN="th__"

while getopts d:q:s:e:z: OPT
do
  case $OPT in
    "d") DDIR=$OPTARG ;;
    "q") Q_IN=$OPTARG ;;
    "s") XS=$OPTARG   ;;
    "e") XE=$OPTARG   ;;
    "z") ZP=$OPTARG   ;;
     * ) exit 1       ;;
  esac
done

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

for N in `seq 0 $NSUM`
do
if [ "$Q_IN" = "th__" ]; then
  F_NAME="t___"${N_IN[$N]}
else
  F_NAME=${Q_IN}${N_IN[$N]}
fi
$SDIR/bin2prf << EOF1 > $GDIR/$F_OUT.dat$N
&figs
f_name = "$F_NAME"
irec   =  ${IREC[$N]}
/
EOF1
done

cd $GDIR

ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat0`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
YLAB="Height (km)"
XLAB=`awk -v qnt=$Q_IN 'BEGIN {FS=","} $2==qnt {print $3}' $SDIR/vprof.par`
FACT=`awk -v qnt=$Q_IN 'BEGIN {FS=","} $2==qnt {print $4}' $SDIR/vprof.par`

xtick "$F_OUT.dat0"

if [ "$Q_IN" = "q___" -o "$Q_IN" = "zwt_" ]; then
  XPOS=`echo "scale=2; $XLEN-2.4" | bc`
else
  XPOS=1.6
fi

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

### Base map
psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"$XLAB":/a0.5f0.1:"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
if [ `echo $Q_IN | cut -c-2` = "zw" -a \( $XS -lt 0 -a $XE -gt 0 \) ]; then
  { echo 0 0; echo 0 $ZP; } | \
  psxy -JX -R -W2 -K -O >> $F_OUT.ps
fi

for N in `seq 0 $NSUM`
do
  TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat$N`

  YPOS=`echo "scale=2; $YLEN-1.7-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v fact=$FACT 'NR > 4 {print $1*fact, $2/1000.0}' $F_OUT.dat$N | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$N]} -K -O >> $F_OUT.ps

### Legend
  echo $XPOS $YPOS 12 0 0 LM "${NLBL[$N]}" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
done

YPOS=`echo "scale=2; $YLEN-0.9" | bc`
echo 0.6 $YPOS 12 0 0 LM "Time  $TIME" | \
pstext -JX -R -O >> $F_OUT.ps

# rm -f $F_OUT.dat*

kghostview $F_OUT.ps
