#!/bin/sh

# Displays temporal variations

. ./Xtick.sh

DDIR=/work1/les
# N_IN=("21.01" "21.01" "21.01")
# IREC=(1 2 3)
N_IN=("41.01" "41.01" "41.01" "41.01")
IREC=(3 4 5 6)
# LINE=("W8" "W8t25_15:0" "W8t10_15:0" "W8t30_10_10_10:0")
LINE=("W8/255/64/64" "W8t25_15:0/192/64/255" "W8t10_15:0/128/32/255" "W8t30_10_10_10:0/0/0/128")
# LINE=("W8/255/64/64" "W8/192/64/255" "W8/128/32/255" "W8/0/0/128")

NSUM=`expr ${#IREC[@]} - 1`

Q_IN="th__"
YLAB=":Height (km):"
TITLE=""

while getopts d:q:s:e:z:t:x OPT
do
  case $OPT in
    "d") DDIR=$OPTARG ;;
    "q") Q_IN=$OPTARG ;;
    "s") XS=$OPTARG   ;;
    "e") XE=$OPTARG   ;;
    "z") ZP=$OPTARG   ;;
    "t") TITLE=$OPTARG ;;
    "x") YLAB=""      ;;
     * ) exit 1       ;;
  esac
done

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

if [ "$Q_IN" = "ws__" ]; then
  P_NAME=$SDIR/bin2prfws
else
  P_NAME=$SDIR/bin2prf
fi

for N in `seq 0 $NSUM`
do
if [ "$Q_IN" = "th__" ]; then
  F_NAME="t___"${N_IN[$N]}
else
  F_NAME=${Q_IN}${N_IN[$N]}
fi
$P_NAME << EOF1 > $GDIR/$F_OUT.dat$N
&figs
f_name = "$F_NAME"
irec   =  ${IREC[$N]}
/
EOF1
done

cd $GDIR

ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat0`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
XLAB=`awk -v qnt=$Q_IN 'BEGIN {FS=","} $2==qnt {print $3}' $SDIR/vprof.par`
FACT=`awk -v qnt=$Q_IN 'BEGIN {FS=","} $2==qnt {print $4}' $SDIR/vprof.par`

xtick "$F_OUT.dat0"

if [ "$Q_IN" = "q___" -o "$Q_IN" = "ws__" ]; then
  XPOS=`echo "scale=2; $XLEN-1.4" | bc`
else
  XPOS=1.6
fi
  YPOS=`echo "scale=2; $YLEN+0.4" | bc`

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.1c
gmtset TICK_LENGTH     -0.2c

### Base map
psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -B"$XTICK":"$XLAB":/a0.5f0.1"$YLAB"WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
if [ `echo $Q_IN | cut -c-2` = "zw" -a \( $XS -lt 0 -a $XE -gt 0 \) ]; then
  { echo 0 0; echo 0 $ZP; } | \
  psxy -JX -R -W2 -K -O >> $F_OUT.ps
fi

if [ -n "$TITLE" ]; then
  echo 0.4 $YPOS 14 0 0 LB "$TITLE" | \
  pstext -JX -R0/$XLEN/0/$YLEN -N -K -O >> $F_OUT.ps
fi

for N in `seq 0 $NSUM`
do
  TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat$N`

  YPOS=`echo "scale=2; $YLEN-0.9-$N*0.5" | bc`
  YPLS=$YPOS

### Profile
  awk -v fact=$FACT 'NR > 4 {print $1*fact, $2/1000.0}' $F_OUT.dat$N | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$N]} -K -O >> $F_OUT.ps

### Legend
  echo $XPOS $YPOS 12 0 0 LM "$TIME" | \
  pstext -JX -R0/$XLEN/0/$YLEN -K -O >> $F_OUT.ps

  if [ $N -lt $NSUM ]; then
    { echo $XPLS $YPLS; echo $XPLE $YPLS; } | \
    psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
  else
    { echo $XPLS $YPLS; echo $XPLE $YPLS; } | \
    psxy -JX -R -${LINE[$N]} -O >> $F_OUT.ps
  fi
done

rm -f $F_OUT.dat*

kghostview $F_OUT.ps
