#!/bin/sh

# Displays case variations for Richardson number

DDIR=/work2/typh
N_IN=("21.02" "22.02")
IREC=(60 60)
# LINE=("W8" "W8t20_10:0")
LINE=("W10" "W5")
NLBL=("100 km" "40 km")

NSUM=`expr ${#IREC[@]} - 1`

XS=-0.1
XE=0.3

while getopts d:s:e:z: OPT
do
  case $OPT in
    "d") DDIR=$OPTARG ;;
    "s") XS=$OPTARG   ;;
    "e") XE=$OPTARG   ;;
    "z") ZP=$OPTARG   ;;
     * ) exit 1       ;;
  esac
done

F_OUT=test
SDIR=$PWD
GDIR=$DDIR/Movie

cd $DDIR

for N in `seq 0 $NSUM`
do
F_NAME="t___"${N_IN[$N]}
$SDIR/bin2prf << EOF1 > $GDIR/$F_OUT.dat$N
&figs
f_name = "$F_NAME"
irec   =  ${IREC[$N]}
/
EOF1

F_NAME="u___"${N_IN[$N]}
$SDIR/bin2prf << EOF1 > $GDIR/$F_OUT.dau$N
&figs
f_name = "$F_NAME"
irec   =  ${IREC[$N]}
/
EOF1

F_NAME="v___"${N_IN[$N]}
$SDIR/bin2prf << EOF1 > $GDIR/$F_OUT.dav$N
&figs
f_name = "$F_NAME"
irec   =  ${IREC[$N]}
/
EOF1
done

cd $GDIR

ZT=`awk 'NR == 3 {print $1}' $F_OUT.dat0`
ZP=`echo "scale=2; ${ZP:=$ZT}/1000.0" | bc`

XLEN=6
YLEN=8
YLAB="Height (km)"
XLAB="Ri"
FACT=1.0

XPOS=1.6

XPLS=`echo "scale=2; $XPOS-1.0" | bc`
XPLE=`echo "scale=2; $XPOS-0.2" | bc`

gmtset ANNOT_FONT_SIZE  12p
gmtset LABEL_FONT_SIZE  12p
gmtset LABEL_OFFSET     0.15c
gmtset TICK_LENGTH     -0.2c

### Base map
psbasemap -JX$XLEN/$YLEN -R$XS/$XE/0/$ZP -Ba0.1f0.05:"$XLAB":/a0.5f0.1:"$YLAB":WeSn -P -X3.0 -Y4.0 -K > $F_OUT.ps
# { echo 0 0; echo 0 $ZP; } | \
# psxy -JX -R -W2 -K -O >> $F_OUT.ps

for N in `seq 0 $NSUM`
do
  TIME=`awk 'NR == 1 {print $1}' $F_OUT.dat$N`

### Profile
  paste $F_OUT.dau$N $F_OUT.dav$N $F_OUT.dat$N | \
  awk 'NR > 4 {print $1, $2, $3, $4, $5}' | \
  awk -f $SDIR/rinum.awk | \
  psxy -JX -R$XS/$XE/0/$ZP -${LINE[$N]} -K -O >> $F_OUT.ps
done

for N in `seq 0 $NSUM`
do
  YPOS=`echo "scale=2; $YLEN-1.7-$N*0.5" | bc`
  YPLS=$YPOS

### Legend
  echo $XPOS $YPOS 12 0 0 LM "${NLBL[$N]}" | \
  pstext -JX -R0/$XLEN/0/$YLEN -W255/255/255 -C0.1 -K -O >> $F_OUT.ps

  { echo $XPLS $YPLS; echo $XPLE $YPLS; } | \
  psxy -JX -R -${LINE[$N]} -K -O >> $F_OUT.ps
done

YPOS=`echo "scale=2; $YLEN-0.9" | bc`
echo 0.6 $YPOS 12 0 0 LM "Time  $TIME" | \
pstext -JX -R -O >> $F_OUT.ps

rm -f $F_OUT.da*

kghostview $F_OUT.ps
