c **********************************************************************
c *   Longwave radiation (Stephens 1978 scheme)                        *
c *                                                                    *
c *   Only effect of clouds to longwave radiation is considered.       *
c *                                                                    *
c *   Output variables:                                                *
c *     rhr(:, 1 ,:)  : Net downward radiative flux           (W/m^2)  *
c *     rhr(:,k+1,:)  : Heating rate at the k-th grid           (K/s)  *
c *     rfx           : Net downward longwave radiative flux  (W/m^2)  *
c *                                                                    *
c *   Work array:                                                      *
c *     uu            : Black-body radiative flux             (W/m^2)  *
c *     ww            : Liquid-water path (LWP)               (g/m^2)  *
c *                                                                    *
c *   Input variables:                                                 *
c *     chour, ..., ulov : not used                                    *
c *     ftop             : Downward flux at the top of domain (W/m^2)  *
c *     fbtm             : Upward flux at the surface         (W/m^2)  *
c **********************************************************************
c
      subroutine  radiation ( chour, rlat, elat, albd, clov, ulov,
     :                        ftop, fbtm )
c
      include  "Declare.h"
c
      sgm = 5.67e-8
c
cx    do j = 2,ny-1
cx    do k = 1,mz
cx    do i = 1,mx
cx      rhr(i,k,j) = 0.0
cx      rfx(i,k,j) = 0.0
cx    end do
cx    end do
cx    end do
c
c  **  Liquid water path (g/m^2)  **
      do j = 2,ny-1
      do i = 2,nx-1
        ww (i,nz+1,j) = 0.0
      end do
      end do
c
      do j = 2,ny-1
      do k = nz,1,-1
      do i = 2,nx-1
        dp = 10.0 * ( p(i,k,j)-p(i,k+1,j) ) / g
        ww (i,k,j) = ww(i,k+1,j) +dp*1.0e4* ql(i,k,j)
      end do
      end do
      end do
c
c  **  Black body radiation  **
      do j = 2,ny-1
      do k = 2,nz+1
      do i = 2,nx-1
        p2a = pi(i,k,j) +pi0(i,k,j)
        tt  = p2a*( t (i,k,j)+t (i,k-1,j)+2.0*tref )
     :       +ev *( ql(i,k,j)+ql(i,k-1,j)          )
        uu (i,k,j) = sgm*( 0.5*tt/cp )**4
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        uu (i,1,j) = uu(i,2,j)
      end do
      end do
c
c  **  Net downward longwave radiative flux (W/m^2)  **
      do j = 2,ny-1
      do k = 1,nz+1
      do i = 2,nx-1
        trdn = exp( -0.158*( ww(i,k,j)-ww(i,nz+1,j) ) )
        trup = exp(  0.130*( ww(i,k,j)-ww(i,   1,j) ) )
c
        rfx(i,k,j) = trdn*ftop +( 1.0-trdn )*uu(i,k,j)
     :              +trup*fbtm -( 1.0-trup )*uu(i,k,j)
      end do
      end do
      end do
c
c  **  Heating rate  **
      do j = 2,ny-1
      do k = 2,nz+1
      do i = 2,nx-1
        pp = 50.0*( pi (i, k ,j)+pi0(i, k ,j)
     :             +pi (i,k-1,j)+pi0(i,k-1,j) )
     :           *( p  (i,k-1,j)-p  (i, k ,j) )
        rhr(i,k,j) = g * ( rfx(i,k,j)-rfx(i,k-1,j) ) / pp
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        rhr(i,1,j) = rfx(i,1,j)
      end do
      end do
c
c?    rsum = 1.0/dble((nx-2)*(ny-2))
c
c?    do k = 1,nz
c?      rhrk = 0.0
c?    do j = 2,ny-1
c?    do i = 2,nx-1
c?      rhrk = rhrk +rhr(i,k,j)
c?    end do
c?    end do
c?      ti(k) = ti(k) +(rhrk*rsum)*dt
c?    end do
c
      return
      end
