c **********************************************************************
c *   Making a file of the observational data                          *
c *                                                                    *
c *   Data stored in the file 'OBS':                                   *
c *     nzob          : Number of observational levels                 *
c *     tref          : Reference 'potential' temperature  (0.1deg.C)  *
c *     tsf           : Temperature at the ground surface  (0.1deg.C)  *
c *     psf           : Pressure    at the ground surface    (0.1hPa)  *
c *     hob           : Height above ground level                 (m)  *
c *     pob           : Pressure                             (0.1hPa)  *
c *     tob           : Temperature                        (0.1deg.C)  *
c *     qob           : Specific humidity                   (0.1g/kg)  *
c *     uob, vob      : Horizontal velocity components      (0.01m/s)  *
c *                                                                    *
c *   # All the data are desirable to be recorded in Integer type.     *
c **********************************************************************
c
      include  "../src/Implicit.h"
c
      parameter ( mob=201 )
      dimension  hob(mob), pob(mob), tob(mob), qob(mob),
     :           uob(mob), vob(mob)
c
      open (12,file='KH.OBS',form='unformatted')
c
      nzob = 201
      tref = 300.0 -273.15
      psf  = 1000.0
c
      h    = 2.0
      zi   = 20.0
      dz   = 0.2
      dt   = 1.0
      du   = 1.0
      gt   = 0.02
c
      do k = 1,nzob
        hob(k) = dz*( k-1 )
        zz = ( hob(k)-zi )/h
        pob(k) = 1000.0
        tob(k) = dt*tanh( zz ) +gt*zz +tref
        qob(k) = 0.0
        uob(k) = du*tanh( zz )
        vob(k) = 0.0
      end do
c
      tsf  = tob(1)
c
      write(12)  nzob, tref, tsf, psf, 0
      write(12)  ( hob(m),m=1,nzob )
      write(12)  ( pob(m),m=1,nzob )
      write(12)  ( tob(m),m=1,nzob )
      write(12)  ( qob(m),m=1,nzob )
      write(12)  ( uob(m),m=1,nzob )
      write(12)  ( vob(m),m=1,nzob )
c
      close(12)
c
      do k = nzob,1,-5
        write(6,*) 'hob,tob,uob=', hob(k), tob(k), uob(k)
      end do
c
      stop
      end
