c **********************************************************************
c *   Karhunen-Loeve (KL) decomposition for POD analysis               *
c *                                                                    *
c *                                   Apr/2007  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_eigen.f"
      include  "sub_KL_decomp.f"
      include  "sub_bc_etc.f"
      include  "../src/fft.f"
      include  "../src/Parameter.h"
c
      parameter ( mc=3, md=mc*(mc+1)/2 )
      double precision  pr(mz,mz,md), pi(mz,mz,md)
      integer           ic(md)/ 1, 1, 1, 2, 2, 3/,
     :                  jc(md)/ 1, 2, 3, 2, 3, 3/
c
      double precision  bi(mx,my,mz,mc), bk(mx,my,mz,mc)
      double precision  ui(mx,my,mz,mc), uav(mz,mc)
      double precision  wk2(mx,my), trix(mx), triy(my)
      dimension         ifax(20), ifay(20)
      double precision  csx(mx), snx(mx), csy(my), sny(my)
c
      double precision  eval(mz*mc),       we2(mz*mc*mz*mc*4)
      double complex    efun(mz*mc,mz*mc), we1(mz*mc*mz*mc)
      integer                              iwe(mz*mc*5)
c
      character (len=4) :: f_name(mc), p_name = 'pa11'
      character (len=5) :: r_num
      double precision  dat(mx,mz,my)
      data              f_name/ 'u___', 'v___', 'w___'/
c
      parameter ( mk=12 )
      integer           kx(mk,mk), ky(mk,mk), mode(mk,mk)
c
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      namelist  /pod1/ r_num, irsta, irend, kmax
      namelist  /pod2/ irdecomp, kx, ky, mode
c
      kmax     = 999
      irdecomp = 999
c
      do j = 1,mk
      do i = 1,mk
        kx(i,j)   = 9999
        ky(i,j)   = 9999
        mode(i,j) = 1
      end do
      end do
c
      read (5,nml=pod1)
      read (5,nml=pod2)
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'Para-file not found.'
c
      read (10,*) lx, lz, ly
c
      if ( lx .ne. mx .or. ly .ne. my .or. lz .ne. mz ) then
        write(6,*) 'mx, my, mz =', mx, my, mz
        write(6,*) 'lx, ly, lz =', lx, ly, lz
        stop 'Grid number is not consistent with Parameter.h!'
      end if
c
      read (10,nml=les2)
      close(10)
c
      nx2 =   nx -2
      ny2 =   ny -2
      nxh = ( nx2-1 )/2 +1
      nyh = ( ny2-1 )/2 +1
c
c   **  Note: Intel compiler option, -assume byterecl, is needed.  **
      lrec = 2*nz*nz * 8
c
      kmax = min( kmax, nz )
      nzc  = kmax*mc
c
      call rfftim ( nx2, trix, ifax )
      call rfftim ( ny2, triy, ifay )
c
      call sub_kl_initial ( nx2, ny2, csx, snx, csy, sny )
c
      do id = 1,md
        write(p_name(3:4),'(2i1)') ic(id), jc(id)
c
        open (30+id,file=p_name//r_num,access='direct',recl=lrec)
      end do
c
      do m = 1,mc
        open (11,  file=f_name(m)//r_num,form='unformatted')
        open (50+m,file='zz'//f_name(m)(1:2)//r_num,form='unformatted')
c
        do ir = 1,irdecomp
          read (11,end=100) dat
        end do
  100   continue
c
        call coeff ( f_name(m) .eq. 'u___', ax1, bx1 )
        call coeff ( f_name(m) .eq. 'v___', ay1, by1 )
        call coeff ( f_name(m) .eq. 'w___', az1, bz1 )
c
        do k = 1,kmax
          do j = 2,ny-1
          do i = 2,nx-1
            bi(i-1,j-1,k,m) = ax1         * dat(i+1,k  ,j  )
     :                      +     ay1     * dat(i  ,k  ,j+1)
     :                      +         az1 * dat(i  ,k+1,j  )
     :                      + bx1*by1*bz1 * dat(i  ,k  ,j  )
          end do
          end do
c
          call rfftfm( nx2, 1,mx,ny2, bi(1,1,k,m), trix,ifax, wk2 )
          call rfftfm( ny2,mx, 1,nx2, bi(1,1,k,m), triy,ifay, wk2 )
        end do
c
        close(11)
      end do
c
      do m = 1,mc
      do k = 1,kmax
          uav(k,m)    = bi(1,1,k,m)
        do j = 1,ny2
        do i = 1,nx2
          bk(i,j,k,m) = bi(i,j,k,m)
          ui(i,j,k,m) = 0.0
        end do
        end do
      end do
      end do
c
      do jj = 1,nyh
      do ii = 1,nx2
        if ( ii .eq. nxh .and. jj .eq. nyh ) exit
        kxm  = ii -nxh
        kym  = jj -nyh
c
        irec = kxm+nxh + nx2*( kym+nyh-1 )
c
        do id = 1,md
          read (30+id,rec=irec) ((pr(k,l,id),pi(k,l,id),k=1,nz),l=1,nz)
        end do
c
        call sub_eigen( 1, pr, pi, mz, kmax, dz, ic, jc, mc, md,
     :                  eval, efun, we1, we2, iwe )
c
        if ( ii .eq. nxh ) write(6,991) 1, kxm, kym, 1, eval(nzc)
c
      do mm = nzc,1,-1
        if ( eval(mm) .lt. 1.0d-3 ) exit
c
        call sub_kl_decomp( 1, bi, mx,my,mz, nx2,ny2,kmax, dz, mc,
     :                  efun(1,mm), kxm,kym, csx,snx,csy,sny, we1 )
c
        do m = 1,mc
        do k = 1,kmax
        do j = 1,ny2
        do i = 1,nx2
          ui(i+1,j+1,k,m) = ui(i+1,j+1,k,m) + bi(i,j,k,m)
          bi( i , j ,k,m) = bk( i , j ,k,m)
        end do
        end do
        end do
        end do
      end do
c
      end do
      end do
c
        do m = 1,mc
          call sub_bc_ijk ( ui(1,1,1,m), mx, my, nx, ny, kmax )
c
          write(50+m) ( ( ( ui(i,j,k,m),i=1,mx ),k=1,mz ),j=1,my )
        end do
c
      stop
  991 format(i2,': Eigenvalue at (',i4,',',i4,') [',i3,'] =',1pe10.2)
      end
c
      subroutine  coeff ( agree, aa, bb )
c
      logical  agree
c
                   aa = 0.0
      if ( agree ) aa = 0.5
                   bb = 1.0 -aa
c
      return
      end
