c **********************************************************************
c *   Decomposition of the specified physical quantity                 *
c *                                                                    *
c *   Results will be delivered to GMT command.                        *
c *                                                                    *
c *                                   Oct/2010  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_KL_decomp.f"
      include  "sub_fourier.f"
      include  "../src/Parameter.h"
c
      double precision  bi(mx,my,mz)
      double precision  csx(mx), snx(mx), csy(my), sny(my)
      dimension         bj(mx,my,mz)
c
      character (len=4) :: f_name
      character (len=5) :: r_num
      double precision  dat(mx,mz,my)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      read (5,*) f_name
      read (5,*) r_num
      read (5,*) irec, kx, ky, jplane, ang
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'Para-file not found.'
c
      read (10,*) lx, lz, ly
c
      if ( lx .ne. mx .or. ly .ne. my .or. lz .ne. mz ) then
        write(6,*) 'mx, my, mz =', mx, my, mz
        write(6,*) 'lx, ly, lz =', lx, ly, lz
        stop 'Grid number is not consistent with Parameter.h!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
c
      open (11,file=f_name//r_num,form='unformatted',status='old')
c
      do i = 1,irec-1
        read (11,end=100)
      end do
        read (11,end=100) dat
c
  100 close(10)
      close(11)
c
      nx2 =   nx -2
      ny2 =   ny -2
c
      call sub_kl_initial ( nx2, ny2, csx, snx, csy, sny )
c
      call coeff ( f_name .eq. 'u___', ax1, bx1 )
      call coeff ( f_name .eq. 'v___', ay1, by1 )
      call coeff ( f_name .eq. 'w___', az1, bz1 )
c
      do k = 1,nz
        do j = 2,ny-1
        do i = 2,nx-1
          bi(i-1,j-1,k) = ax1         * dat(i+1,k  ,j  )
     :                  +     ay1     * dat(i  ,k  ,j+1)
     :                  +         az1 * dat(i  ,k+1,j  )
     :                  + bx1*by1*bz1 * dat(i  ,k  ,j  )
        end do
        end do
      end do
c
      call sub_fourier ( bi, mx, my, nx2, ny2, nz,
     :                   kx, ky, csx, snx, csy, sny )
c
      kxa = abs(kx)
      kya = abs(ky)
      ia  = max( kxa*2, 1 )
      ja  = max( kya*2, 1 )
                       sx = sign(1,kx)
                       sy = sign(1,ky)
      if ( kx .eq. 0 ) sx = 0.0
      if ( ky .eq. 0 ) sy = 0.0
c
      do k = 1,nz
        do j = 1,ny2
        do i = 1,nx2
          ii  = mod( kxa*(i-1), nx2 ) +1
          ani = 2.0*(       bi(ia  ,ja  ,k)*csx(ii)
     :               -sx   *bi(ia+1,ja  ,k)*snx(ii) )
          bni = 2.0*(    sy*bi(ia  ,ja+1,k)*csx(ii)
     :               -sx*sy*bi(ia+1,ja+1,k)*snx(ii) )
c
          jj  = mod( kya*(j-1), ny2 ) +1
          bj(i+1,j+1,k) = 2.0*( ani*csy(jj)-bni*sny(jj) )
cx   :                   +bi(1,1,k)
        end do
        end do
c
        do j = 2,ny-1
          bj( 1, j,k) = bj(nx-1,  j ,k)
          bj(nx, j,k) = bj(  2 ,  j ,k)
        end do
        do i = 1,nx
          bj( i, 1,k) = bj(  i ,ny-1,k)
          bj( i,ny,k) = bj(  i ,  2 ,k)
        end do
      end do
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
      xp   = dx*( nx-2 )
      yp   = dy*( jplane-1.5 )
      zp   = dz*( nz   )
c
      write(6,'(i5.4)') ih
      write(6,*) dx, dy, dz
      write(6,*) xp, yp, zp
      write(6,*) 'pod-decomposition'
c
      d2r = 3.141593/180.0
      cs  = cos( ang*d2r )
      sn  = sin( ang*d2r )
      yy  = 0.0
c
      do k = 1,nz
      do i = 1,nx
        xx  = dx*(i-1.5) * cs + yy * sn
        write(6,*) xx, dz*(k-0.5), bj(i,jplane,k)
      end do
      end do
c
      stop
      end
c
      subroutine  coeff ( agree, aa, bb )
c
      logical  agree
c
                   aa = 0.0
      if ( agree ) aa = 0.5
                   bb = 1.0 -aa
c
      return
      end
