c **********************************************************************
c *   Spectral densities from POD analysis (versus height)             *
c *                                                                    *
c *     iqnt : = 1, u; = 2, v; = 3, w                                  *
c *                                                                    *
c *                                   Jun/2010  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "../src/Parameter.h"
      include  "Paramodif.h"
c
      parameter ( mc=3 )
      double precision  pr(mz,mz), pi(mz,mz)
c
      character (len=4) :: p_name = 'pa11'
      character (len=5) :: r_num
      double precision  spd(mmx,mmy,mz), spdsum
c
      parameter ( mxy=max(mmx,mmy)*15, del=0.2 )
      dimension  spx(mxy,mz), xco(mxy,mz), kx(mxy,mz), ky(mxy,mz)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      namelist  /pod1/ r_num, irsta, irend, kmax
      namelist  /pod3/ iqnt, iplane, jplane, kplane
c
      irsta    = 1
      irend    = 999
      iqnt     = 1
c
      read (5,nml=pod1)
      read (5,nml=pod3)
c
      if ( iqnt .lt. 1 .or. iqnt .gt. mc ) stop 'iqnt error'
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'Para-file not found.'
c
      read (10,*) lx, lz, ly
c
      if ( lx .ne. mx .or. ly .ne. my .or. lz .ne. mz ) then
        write(6,*) 'mx, my, mz =', mx, my, mz
        write(6,*) 'lx, ly, lz =', lx, ly, lz
        stop 'Grid number is not consistent with Parameter.h!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
      close(10)
c
      nx2 = ( nx -2 )/mskip
      ny2 = ( ny -2 )/mskip
      nxh = ( nx2-1 )/2 +1
      nyh = ( ny2-1 )/2 +1
c
c   **  Note: Intel compiler option, -assume byterecl, is needed.  **
      lrec = 2*nz*nz * 8
c
      do id = iqnt,iqnt
        write(p_name(3:4),'(2i1)') id, id
c
        open (30+id,file=p_name//r_num,access='direct',recl=lrec)
      end do
c
      do j = 1,nyh
      do i = 1,nxh*2-1
        irec = i + nx2*( j-1 )
c
        do id = iqnt,iqnt
          read (30+id,rec=irec) ((pr(k,l),pi(k,l),k=1,nz),l=1,nz)
        end do
c
        do k = 1,nz
          spd(i,j,k) = pr(k,k)
        end do
      end do
      end do
c
        nsum = 0
cx      nsum = 100
cx      nsum = nxh*2*( nyh-1 )
c
      if ( nsum .gt. 0 ) then
        do k = 1,nz
          spdsum = 0.0
c
          do j = 1,nyh
          do i = 1,nxh*2-1
            if ( j .eq. nyh .and. i .ge. nxh ) exit
            spdsum = spdsum + spd(i,j,k)
          end do
          end do
c
          do j = 1,nyh
          do i = 1,nxh*2-1
            spd(i,j,k) = spd(i,j,k)/spdsum * nsum
          end do
          end do
        end do
      end if
c
c   **  obtains maximum every del-wavenumber  **
      imax = sqrt( (nxh-1.0)**2+(nyh-1.0)**2 )/del +0.5
c
      do k = 1,nz
      do i = 1,mxy
        spx(i,k) = 0.0
        xco(i,k) = i*del
      end do
      end do
c
      do j = 1,nyh
      do i = 1,nxh*2-1
        if ( j .eq. nyh .and. i .ge. nxh ) exit
        rx   = i -nxh
        ry   = j -nyh
        xlam = sqrt( rx**2+ry**2 )
        ilam = xlam/del +0.5
c
        do k = 1,nz
          if ( spd(i,j,k) .gt. spx(ilam,k) ) then
            spx(ilam,k) = spd(i,j,k)
            xco(ilam,k) = xlam
            kx (ilam,k) = nxh -i
            ky (ilam,k) = nyh -j
          end if
        end do
      end do
      end do
c
      ihs  = jmin +nint(min(nstot-nstep+jout*irsta,nstot)*dt)/60
      ihs  = ihs/60*100 +mod(ihs,60)
      ihe  = jmin +nint(min(nstot-nstep+jout*irend,nstot)*dt)/60
      ihe  = ihe/60*100 +mod(ihe,60)
      xp   = del*imax
      yp   = del*imax
      zp   = dz *nz
c
      write(6,'(2i5.4)') ihs, ihe
      write(6,*) del, del, dz
      write(6,*) xp, yp, zp
      write(6,*) 'x-z'
c
      do k = 1,nz
      do i = 1,imax
        write(6,*) xco(i,k), dz*(k-0.5), spx(i,k), kx(i,k), ky(i,k)
      end do
      end do
c
      stop
      end
