c
      subroutine  sub_kl_decomp (
     i                    iflag,
     m                    bi,
     i                    mx, my, mz, nx2, ny2, nz, dz, mc,
     i                    efun, kx, ky,
     i                    csx, snx, csy, sny,
     o                    aa )
c
c     Input variables:
c       iflag           : = 0; calculates only projection coefficient.
c                         > 0; transforms bi into the flow fields.
c                         < 0; calculates the flow fields for aa=0.
c       bi              : Fourier coefficients of velocity components
c       dz              : Vertical grid spacing (Note: single precision)
c       efun            : Eigenfunction for wavenumber (kx,ky)
c                         -nxh < kx < nxh, -nyh < ky < nyh
c       csx, ..., sny   : Table of the trigonometric functions,
c                         obtained from sub_kl_initial
c
c     Output variables:
c       bi              : Velocity components for the specified eigenfunc.
c       aa              : Projection coefficient for wavenumber (kx,ky)
c
c       A description of the Fourier coefficients bi is referred to
c     the document of FFTPACK developed by P. N. Swarztrauber at NCAR.
c
      double precision  bi(mx,my,mz,mc)
      double precision  csx(mx), snx(mx), csy(my), sny(my)
      double precision  er, ei, tr, ti
      double complex    efun(mz*mc)
      double complex    aa, bb
c
      nxh = ( nx2-1 )/2 +1
      nyh = ( ny2-1 )/2 +1
c
      if ( abs(kx) .ge. nxh .or. abs(ky) .ge. nyh .or.
     :     ( kx .eq. 0 .and. ky .eq. 0 ) ) then
        write(6,*) 'Skip: wavenumber (kx,ky) =', kx, ky
        return
      end if
c
      if ( iflag .lt. 0 ) then
          aa = ( 1.0d0, 0.0d0 )
c
      else
        i  = max( abs(kx)*2, 1 )
        j  = max( abs(ky)*2, 1 )
                         sx = sign(1,kx)
                         sy = sign(1,ky)
        if ( kx .eq. 0 ) sx = 0.0
        if ( ky .eq. 0 ) sy = 0.0
c
          aa = ( 0.0d0, 0.0d0 )
c
        do m = 1,mc
        do k = 1,nz
          bb = dcmplx(    bi(i  ,j  ,k,m) - sx*sy*bi(i+1,j+1,k,m),
     :                 sx*bi(i+1,j  ,k,m) +    sy*bi(i  ,j+1,k,m) )
c
          aa = aa + bb * conjg( efun(k+nz*(m-1)) )
        end do
        end do
c
          aa = aa * dble(dz)
      end if
c
      if ( iflag .eq. 0 ) return
c
c  ***  Backward Fourier transform  ***
      iadd = abs(kx) * nx2
      jadd = abs(ky) * ny2
c
      do j = 1,ny2
      do i = 1,nx2
        ii = mod( kx*(i-1)+iadd, nx2 ) +1
        jj = mod( ky*(j-1)+jadd, ny2 ) +1
c
c   **  2.0 means the sum of fields at (kx,ky) and (-kx,-ky).  **
        tr = 2.0*( csx(ii)*csy(jj) - snx(ii)*sny(jj) )
        ti = 2.0*( snx(ii)*csy(jj) + csx(ii)*sny(jj) )
c
        do m = 1,mc
        do k = 1,nz
          er = dble( aa * efun(k+nz*(m-1)) )
          ei = imag( aa * efun(k+nz*(m-1)) )
c
          bi(i,j,k,m) = er*tr - ei*ti
        end do
        end do
c
      end do
      end do
c
      return
      end
c
      subroutine  sub_kl_initial (
     i                    nx2, ny2,
     o                    csx, snx, csy, sny )
c
      double precision  csx(nx2), snx(nx2), csy(ny2), sny(ny2)
c
      do i = 1,nx2
        csx(i) = cos( 6.28318530717959d0*dble(i-1)/dble(nx2) )
        snx(i) = sin( 6.28318530717959d0*dble(i-1)/dble(nx2) )
      end do
      do j = 1,ny2
        csy(j) = cos( 6.28318530717959d0*dble(j-1)/dble(ny2) )
        sny(j) = sin( 6.28318530717959d0*dble(j-1)/dble(ny2) )
      end do
c
      return
      end
