c
      subroutine  sub_cross_spec (
     i                    bi, bj, mx, my, mz, nx2, ny2, nz,
     o                    pr, pi )
c
c     Input variables:
c       bi, bj          : Fourier coefficients of the i-component and
c                         j-component, respectively.
c
c     Output variables:
c       pr, pi          : Real and imaginary parts of the cross-spectrum of
c                         both components, respectively.
c                         Perturbation with two-grid wavelength is removed.
c
c       A description of the Fourier coefficients bi and bj is referred to 
c     the document of FFTPACK developed by P. N. Swarztrauber at NCAR.
c
      double precision  bi(mx,my,nz),    bj(mx,my,nz)
      double precision  pr(mx,my,mz,nz), pi(mx,my,mz,nz)
c
      nxh = ( nx2-1 )/2 +1
      nyh = ( ny2-1 )/2 +1
c
      do l = 1,nz
      do k = 1,nz
c
        do j = 2,nyh
        do i = 2,nxh
          ipp = nxh +i -1
          ipm = nxh -i +1
          jpp = nyh +j -1
          jpm = nyh -j +1
          ib  = ( i-1 )*2
          jb  = ( j-1 )*2
c
          pr(ipp,jpp,k,l) =  pr(ipp,jpp,k,l)
     :                    +( bi(ib  ,jb  ,k) - bi(ib+1,jb+1,k) )
     :                    *( bj(ib  ,jb  ,l) - bj(ib+1,jb+1,l) )
     :                    +( bi(ib+1,jb  ,k) + bi(ib  ,jb+1,k) )
     :                    *( bj(ib+1,jb  ,l) + bj(ib  ,jb+1,l) )
          pi(ipp,jpp,k,l) =  pi(ipp,jpp,k,l)
     :                    -( bi(ib  ,jb  ,k) - bi(ib+1,jb+1,k) )
     :                    *( bj(ib+1,jb  ,l) + bj(ib  ,jb+1,l) )
     :                    +( bi(ib+1,jb  ,k) + bi(ib  ,jb+1,k) )
     :                    *( bj(ib  ,jb  ,l) - bj(ib+1,jb+1,l) )
c
          pr(ipm,jpm,k,l) =  pr(ipp,jpp,k,l)
          pi(ipm,jpm,k,l) = -pi(ipp,jpp,k,l)
c
          pr(ipm,jpp,k,l) =  pr(ipm,jpp,k,l)
     :                    +( bi(ib  ,jb  ,k) + bi(ib+1,jb+1,k) )
     :                    *( bj(ib  ,jb  ,l) + bj(ib+1,jb+1,l) )
     :                    +( bi(ib+1,jb  ,k) - bi(ib  ,jb+1,k) )
     :                    *( bj(ib+1,jb  ,l) - bj(ib  ,jb+1,l) )
          pi(ipm,jpp,k,l) =  pi(ipm,jpp,k,l)
     :                    +( bi(ib  ,jb  ,k) + bi(ib+1,jb+1,k) )
     :                    *( bj(ib+1,jb  ,l) - bj(ib  ,jb+1,l) )
     :                    -( bi(ib+1,jb  ,k) - bi(ib  ,jb+1,k) )
     :                    *( bj(ib  ,jb  ,l) + bj(ib+1,jb+1,l) )
c
          pr(ipp,jpm,k,l) =  pr(ipm,jpp,k,l)
          pi(ipp,jpm,k,l) = -pi(ipm,jpp,k,l)
        end do
        end do
c
        do i = 2,nxh
          ipp = nxh +i -1
          ipm = nxh -i +1
          jp  = nyh
          ib  = ( i-1 )*2
          jb  = 1
c
          pr(ipp,jp ,k,l) =  pr(ipp,jp ,k,l)
     :                    +  bi(ib  ,jb  ,k)
     :                    *  bj(ib  ,jb  ,l)
     :                    +  bi(ib+1,jb  ,k)
     :                    *  bj(ib+1,jb  ,l)
          pi(ipp,jp ,k,l) =  pi(ipp,jp ,k,l)
     :                    -  bi(ib  ,jb  ,k)
     :                    *  bj(ib+1,jb  ,l)
     :                    +  bi(ib+1,jb  ,k)
     :                    *  bj(ib  ,jb  ,l)
c
          pr(ipm,jp ,k,l) =  pr(ipp,jp ,k,l)
          pi(ipm,jp ,k,l) = -pi(ipp,jp ,k,l)
        end do
c
        do j = 2,nyh
          ip  = nxh
          jpp = nyh +j -1
          jpm = nyh -j +1
          ib  = 1
          jb  = ( j-1 )*2
c
          pr(ip ,jpp,k,l) =  pr(ip ,jpp,k,l)
     :                    +  bi(ib  ,jb  ,k)
     :                    *  bj(ib  ,jb  ,l)
     :                    +                    bi(ib  ,jb+1,k)
     :                    *                    bj(ib  ,jb+1,l)
          pi(ip ,jpp,k,l) =  pi(ip ,jpp,k,l)
     :                    -  bi(ib  ,jb  ,k)
     :                    *                    bj(ib  ,jb+1,l)
     :                    +                    bi(ib  ,jb+1,k)
     :                    *  bj(ib  ,jb  ,l)
c
          pr(ip ,jpm,k,l) =  pr(ip ,jpp,k,l)
          pi(ip ,jpm,k,l) = -pi(ip ,jpp,k,l)
        end do
c
          pr(nxh,nyh,k,l) =  pr(nxh,nyh,k,l)
     :                    +  bi(1   ,1   ,k)
     :                    *  bj(1   ,1   ,l)
c
      end do
      end do
c
      return
      end
