c
      subroutine  sub_eigen (
     i                    iflag, pr, pi, mz, nz, dz,
     i                           ic, jc, mc, md,
     o                    eval, efun,
     w                    wk1, wk2, iwk )
c
c     Input variables:
c       iflag           : = 0; calculates only eigenvalues.
c                         <>0; calculates eigenvalues and eigenfunctions.
c       pr, pi          : Real and imaginary parts of the cross-spectrum of
c                         velocity components, respectively.
c       dz              : Vertical grid spacing (Note: single precision)
c       ic, jc          : Indices of velocity components ui. If mc = 3,
c                         ic (md=6) = 1, 1, 1, 2, 2, and 3,
c                         jc (md=6) = 1, 2, 3, 2, 3, and 3.
c
c     Output variables:
c       eval            : Eigenvalue
c       efun            : Eigenfunction (at first cross-correlation tensor)
c
c       An arrangement of the matrix efun is referred to the document of
c     LAPACK at http://www.netlib.org/lapack/.
c
      double precision  pr(mz,mz,md), pi(mz,mz,md),  esum
      integer           ic(md), jc(md)
      double precision  eval(mz*mc),       wk2(*)
      double complex    efun(mz*mc,mz*mc), wk1(*)
      integer                              iwk(*)
      character*1       job
c
c  ***  Cross-correlation tensor of velocity components  ***
      do m = 1,md
      do l = 1,nz
      do k = 1,nz
        i  = k + nz*( ic(m)-1 )
        j  = l + nz*( jc(m)-1 )
c
        efun(i,j) = dcmplx( pr(k,l,m), pi(k,l,m) ) * dble(dz)
      end do
      end do
      end do
c
                          job = 'V'
      if ( iflag .eq. 0 ) job = 'N'
c
      nzc  = nz*mc
      nwk1 =   nzc*nzc + 1 + nzc* 2
      nwk2 = 3*nzc*nzc + 2 + nzc*(4+2*int(log(real(nzc))/log(2.0)+1.0))
      niwk = 5*nzc     + 3
c
      call zheevd ( job, 'U', nzc, efun, mz*mc, eval,
     :              wk1, nwk1, wk2, nwk2, iwk, niwk, info )
c
      if ( info  .ne. 0 ) write(6,*) 'Eigenanalysis info :', info
c
      if ( iflag .eq. 0 ) return
c
c  ***  Renormalization of the eigenfunctions  ***
      do j = 1,nzc
          esum = 0.0d0
        do i = 1,nzc
          esum = esum + efun(i,j)*conjg(efun(i,j)) * dble(dz)
        end do
c
        if ( esum .eq. 0.0d0 ) then
          esum = 1.0d0
        else
          esum = 1.0d0/sqrt(esum)
        end if
c
        do i = 1,nzc
          efun(i,j) = efun(i,j) * esum
        end do
      end do
c
      return
      end
