c **********************************************************************
c *   Calculates inertial stability parameter for typhoon vortex       *
c *                                                                    *
c *   Input parameters:                                                *
c *     r_num         : Run number                      (Run.Restart)  *
c *                   : For example, 01.01                             *
c *     irec          : Record number to be extracted                  *
c *                                                                    *
c *                                   Jun/2011  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_data_dir.f"
c
      include  "../src/Implicit.h"
c
      parameter ( mx=502, my=502, mz=201 )
      parameter ( mip=1, mm=2 )
c
      character (len=5) :: r_num
      character (len=4) :: f_name(mip) =
     3                 (/'v___'/)
c
      dimension  v (mx,mz,my)
c
      dimension  vav(mx), vor(mx), wok(1-mm:mx+mm)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
      namelist  /les3/  xbub,  ybub,  zbub,   xbr,   ybr,   zbr,  tbub,
     :                  reye
c
      namelist  /post/ r_num, irec, iplane, jplane, kplane
c
      r_num    = ''
      irec     = 1
      iplane   = 0
      jplane   = 0
      kplane   = 1
c
      read (5,nml=post)
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
      read (10,nml=les3)
c
      close(10)
c
c ***
      fst = 0.0
      fc  = 0.0
      if ( abs(rlat) .le. 90.0 ) then
        fst = 2.0*7.292e-5*sin( rlat*3.141593/180.0 )
cx      fc  = 2.0*7.292e-5*cos( rlat*3.141593/180.0 )
      end if
c
      vgeo = sqrt( ugsf**2+vgsf**2 )
c ***
c
      do m = 1,mip
        mt = m +20
c
        call sub_data_open ( r_num,f_name(m), mt, lx,lz,ly )
c
        select case ( f_name(m) )
          case ( 'v___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, v   )
        end select
      end do
c
      do i = 1,nx
          vavi = 0.0
        do j = 2,ny-1
          vavi = vavi +v (i,kplane,j)
        end do
          vav(i) = vavi / dble(ny-2)
      end do
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
      xp   = dx*( nx-2 )
      zp   = dz*( kplane-0.5 )
c
      write(6,'(i5.4)') ih
      write(6,*) dx, dz
      write(6,*) nint(xp), nint(zp)
      write(6,*) 'Inertial stability parameter'
c
      do i = 2,nx
        wok(i) = ( fst +    ( vav(i)+vav(i-1) ) / reye )
     :          *( fst +    ( vav(i)-vav(i-1) ) / dx
     :                 +0.5*( vav(i)+vav(i-1) ) / reye
     :                                                 )
      end do
c
      call run_mean ( wok, nx, mm, vor )
c
      do i = 2,nx
        write(6,*) real(vor(i)), real(dx*(i-2.0))
      end do
c
  999 stop
      end
c
      subroutine  run_mean ( x, nx, nm, y )
c
      include  "../src/Implicit.h"
c
      dimension  x(1-nm:nx+nm), y(nx)
c
      do i = 1-nm,1
        x(i) = x(nx+i-2)
      end do
      do i = nx,nx+nm
        x(i) = x(i-nx+2)
      end do
c
      do j = 1,nx
        is = j -nm
        ie = j +nm
        a  = 0.0
c
        do i = is,ie
          a  = a + x(i)
        end do
c
        y(j) = a / dble(ie-is+1)
      end do
c
      return
      end
