c **********************************************************************
c *   Calculates Inertial stability parameter                          *
c *                                                                    *
c *   Input parameters:                                                *
c *     r_num         : Run number                      (Run.Restart)  *
c *                   : For example, 01.01                             *
c *     irec          : Record number to be extracted                  *
c *                                                                    *
c *                                   Oct/2010  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_bc.f"
      include  "sub_vor.f"
      include  "sub_data_dir.f"
c
      include  "../src/Implicit.h"
c
      parameter ( mx=502, my=502, mz=201 )
      parameter ( mip=3, one=1.0 )
c
      character (len=5) :: r_num
      character (len=4) :: f_name(mip) =
     3                 (/'u___', 'v___', 'w___' /)
c
      dimension  u (mx,mz,my), v (mx,mz,my), w (mx,mz,my)
c
      dimension  zx(mx,mz,my), zy(mx,mz,my), zz(mx,mz,my)
      dimension  ave(mx,my), bve(mx,my)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
      namelist  /les3/  xbub,  ybub,  zbub,   xbr,   ybr,   zbr,  tbub,
     :                  reye
c
      namelist  /post/ r_num, irec, iplane, jplane, kplane
c
      r_num    = ''
      irec     = 1
      iplane   = 0
      jplane   = 0
      kplane   = 1
c
      read (5,nml=post)
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
      read (10,nml=les3)
c
      close(10)
c
c ***
      fst = 0.0
      fc  = 0.0
      if ( rlat .le. 90.0 ) then
        fst = 2.0*7.292e-5*sin( rlat*3.141593/180.0 )
cx      fc  = 2.0*7.292e-5*cos( rlat*3.141593/180.0 )
      end if
c
      vgeo = sqrt( ugsf**2+vgsf**2 )
c ***
c
      do m = 1,mip
        mt = m +20
c
        call sub_data_open ( r_num,f_name(m), mt, lx,lz,ly )
c
        select case ( f_name(m) )
          case ( 'u___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, u   )
          case ( 'v___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, v   )
          case ( 'w___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, w   )
        end select
      end do
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
      xp   = dx*( nx-2 )
      yp   = dy*( ny-2 )
      zp   = dz*( kplane-0.5 )
c
      write(6,'(i5.4)') ih
      write(6,*) real(dx), real(dy), real(dz)
      write(6,*) real(xp), real(yp), real(zp)
      write(6,*) 'x-y'
c
        call sub_vor (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w,
     o                  zx, zy, zz )
c
      do j = 1,ny
      do i = 1,nx
        im1 = i - 1; if ( im1 .lt. 1 ) im1 = im1 + nx-2
c
        ave(i,j) = ( fst+( v (i,kplane,j)+v (im1,kplane,j) )/reye )
     :            *( fst+  zz(i,kplane,j) )
c?      ave(i,j) = ( fst+  zz(i,kplane,j) )
      end do
      end do
c
      call smooth ( ave, mx, nx, ny, bve )
      call smooth ( ave, mx, nx, ny, bve )
      call smooth ( ave, mx, nx, ny, bve )
c
      do j = 2,ny
      do i = 2,nx
        write(6,*) real(dx*(i-2.0)), real(dy*(j-2.0)), real(ave(i,j))
      end do
      end do
c
  999 stop
      end
c
      subroutine  smooth ( x, mx, nx, ny, y )
c
      include  "../src/Implicit.h"
c
      dimension  x(mx,ny), y(mx,ny)
c
      do j = 2,ny-1
      do i = 2,nx-1
        y(i,j) = ( x(i+1,j+1)+x(i-1,j+1)+x(i+1,j-1)+x(i-1,j-1)
     :      +2.0*( x(i+1, j )+x( i ,j+1)+x( i ,j-1)+x(i-1, j ) )
     :      +4.0*  x( i , j ) ) / 16.0
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        x(i,j) = y(i,j)
      end do
      end do
c
      return
      end
