c **********************************************************************
c *   Dissipation rate (EPS)                                           *
c **********************************************************************
c
c    The dissipation <EPS> may be equal to the horizontal average of
c  the subgrid-scale dissipation eps". In this LES model, however, the
c  subgrid-scale motions are assumed to be in a state of local equilib-
c  rium (the diffusion is neglected), and EPS is estimated as follows.
c    The dissipation <eps> for the resolved-scale TKE is
c      <eps> = -<u_i'd(tau_ij')/dx_j>
c            = -<u_i'd(tau_ij)/dx_j>
c            = -d<u_i'tau_ij>/dx_j +<tau_ij du_i'/dx_j>
c            = -d<u_i'tau_ij>/dx_j +<tau_ij du_i/dx_j>
c                                  -<tau_ij>d<u_i>/dx_j
c            = - <A> + <B> - <C>,
c  where u_i and <u_i> are the resolved-scale and ensemble-average
c  velocity components, respectively, u_i = <u_i> + u_i', and
c  tau_ij = K_m (du_i/dx_j + du_j/dx_i).
c    Since B and -<C> lead to the subgrid-scale shear production and a
c  part of the total one, the contribution of eps to EPS is -A, and
c  EPS = -A + eps". Since eps" = Ce*tke"**(3/2)/delta, EPS is
c      EPS = - A + Ce*tke"**(3/2)/delta,
c  where Ce = Ck**3/Cs**4 = 0.1**3/0.18**4 = 0.9526.
c
      subroutine  sub_eps (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uav, vav,
     w                  uu, vv, ww, uv, vw, wu,
     o                  eps )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny), fm(mx,mz,ny)
      dimension  gam(mz), fwu(mz), fvw(mz), flm(mx,ny)
      dimension  uav(mz), vav(mz)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny), ww(mx,mz,ny)
      dimension  uv(mx,mz,ny), vw(mx,mz,ny), wu(mx,mz,ny)
      dimension  eps(mx,mz,ny)
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      anu  = 1.5e-5
      cel  = 1.0/( 0.1*(dx*dy*dz)**(1.0/3.0) )
      cep  = 0.9526/   (dx*dy*dz)**(1.0/3.0)
c
      do k = 1,nz+1
        uav(k) = 0.0
        vav(k) = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          uav(k) = uav(k) +u (i,k,j)
          vav(k) = vav(k) +v (i,k,j)
        end do
        end do
        uav(k) = uav(k) * rsum
        vav(k) = vav(k) * rsum
      end do
c
      do j = 1,ny-1
      do k = 1,nz
        gamk = gam(k)
      do i = 1,nx-1
        f0   = 2.0    *( gamk*fm(i,k,j) +anu )
        sub  = 2.0/3.0*(      fm(i,k,j) *cel )**2
c
        uu(i,k,j) =  f0  *( u (i+1, k , j )-u (i,k,j) ) / dx - sub
        vv(i,k,j) =  f0  *( v ( i , k ,j+1)-v (i,k,j) ) / dy - sub
        ww(i,k,j) =  f0  *( w ( i ,k+1, j )-w (i,k,j) ) / dz - sub
      end do
      end do
      end do
c
      do j = 2,ny
      do k = 1,nz
        gamk = gam(k)
c
        m    = k +1
        gamm = 0.5*( gam(m)+gam(m-1) )
        f11  = fwu(m)
        f22  = fvw(m)
      do i = 2,nx
        f0   = 0.25*gamk*( fm( i , k , j )+fm(i-1, k , j )
     :                    +fm( i , k ,j-1)+fm(i-1, k ,j-1) ) +anu
c
        uv(i,k,j) =  f0*( ( u (i,k,j)-u ( i , k ,j-1) ) / dy
     :                   +( v (i,k,j)-v (i-1, k , j ) ) / dx )
c
        f1   = 0.25*gamm*( fm( i , m , j )+fm(i-1, m , j )
     :                    +fm( i ,m-1, j )+fm(i-1,m-1, j ) ) +anu
        f2   = 0.25*gamm*( fm( i , m , j )+fm( i , m ,j-1)
     :                    +fm( i ,m-1, j )+fm( i ,m-1,j-1) ) +anu
c
        wu(i,m,j) =  f1*( ( u (i,m,j)-u ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w (i-1, m , j ) ) / dx )
     :              +f11
        vw(i,m,j) =  f2*( ( v (i,m,j)-v ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w ( i , m ,j-1) ) / dy )
     :              +f22
      end do
      end do
      end do
c
c  ***  Boundary condition  ***
      do j = 2,ny
      do i = 2,nx
        wu(i,   1,j) = 0.0
        vw(i,   1,j) = 0.0
        wu(i,nz+1,j) = 0.0
        vw(i,nz+1,j) = 0.0
      end do
      end do
c
      do j = ny-1,2,-1
      do k = 1,nz
        km1 = max( k-1, 1 )
      do i = nx-1,2,-1
        uu(i,k,j) = -0.5*( ( u (i+1,k, j )+u ( i ,k, j )-2.0*uav(k) )
     :                    *  uu( i ,k, j )
     :                    -( u ( i ,k, j )+u (i-1,k, j )-2.0*uav(k) )
     :                    *  uu(i-1,k, j ) ) / dx
     :              -0.5*( ( u ( i ,k,j+1)+u ( i ,k, j )-2.0*uav(k) )
     :                    *  uv( i ,k,j+1)
     :                    -( u ( i ,k, j )+u ( i ,k,j-1)-2.0*uav(k) )
     :                    *  uv( i ,k, j ) ) / dy
     :              -0.5*( ( u (i,k+1,j)+u (i, k ,j)-uav(k+1)-uav(k) )
     :                    *  wu(i,k+1,j)
     :                    -( u (i, k ,j)+u (i,km1,j)-uav(km1)-uav(k) )
     :                    *  wu(i, k ,j) ) / dz
c
        vv(i,k,j) = -0.5*( ( v (i+1,k, j )+v ( i ,k, j )-2.0*vav(k) )
     :                    *  uv(i+1,k, j )
     :                    -( v ( i ,k, j )+v (i-1,k, j )-2.0*vav(k) )
     :                    *  uv( i ,k, j ) ) / dx
     :              -0.5*( ( v ( i ,k,j+1)+v ( i ,k, j )-2.0*vav(k) )
     :                    *  vv( i ,k, j )
     :                    -( v ( i ,k, j )+v ( i ,k,j-1)-2.0*vav(k) )
     :                    *  vv( i ,k,j-1) ) / dy
     :              -0.5*( ( v (i,k+1,j)+v (i, k ,j)-vav(k+1)-vav(k) )
     :                    *  vw(i,k+1,j)
     :                    -( v (i, k ,j)+v (i,km1,j)-vav(km1)-vav(k) )
     :                    *  vw(i, k ,j) ) / dz
      end do
      end do
      end do
c
c  ***  Boundary condition  ***
      call sub_bc ( mx, mz, nx, nz, ny, uu )
      call sub_bc ( mx, mz, nx, nz, ny, vv )
c
      do j = 2,ny-1
      do i = 2,nx-1
        ww(i,nz+1,j) =  ( ( w (i,nz+1,j)+w (i,  nz,j) )
     :                   *  ww(i,  nz,j) ) / dz
      end do
      end do
c
      do j = 2,ny-1
      do k = nz,2,-1
      do i = 2,nx-1
        ww(i,k,j) = -0.5*( ( w (i+1,k, j )+w ( i ,k, j ) )
     :                    *  wu(i+1,k, j )
     :                    -( w ( i ,k, j )+w (i-1,k, j ) )
     :                    *  wu( i ,k, j ) ) / dx
     :              -0.5*( ( w ( i ,k,j+1)+w ( i ,k, j ) )
     :                    *  vw( i ,k,j+1)
     :                    -( w ( i ,k, j )+w ( i ,k,j-1) )
     :                    *  vw( i ,k, j ) ) / dy
     :              -0.5*( ( w (i,k+1,j)+w (i, k ,j) )
     :                    *  ww(i, k ,j)
     :                    -( w (i, k ,j)+w (i,k-1,j) )
     :                    *  ww(i,k-1,j) ) / dz
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        ww(i,   1,j) = -( ( w (i,   2,j)+w (i,   1,j) )
     :                   *  ww(i,   1,j) ) / dz
      end do
      end do
c
      do j = 2,ny-1
      do k = 1,nz
      do i = 2,nx-1
        eps(i,k,j) = 0.5*( uu(i+1, k , j )+uu( i , k , j )
     :                    +vv( i , k ,j+1)+vv( i , k , j )
     :                    +ww( i ,k+1, j )+ww( i , k , j ) )
     :              +cep*( fm(i,k,j) *cel )**3
      end do
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, eps )
c
      return
      end
