c **********************************************************************
c *   Dissipation rate (eps)                                           *
c **********************************************************************
c
c    The dissipation <eps> for the resolved-scale TKE is
c      <eps> = -<u_i'd(tau_ij')/dx_j>
c            = -<u_i'd(tau_ij)/dx_j>
c  where u_i and <u_i> are the resolved-scale and ensemble-average
c  velocity components, respectively, u_i = <u_i> + u_i', and
c  tau_ij = K_m (du_i/dx_j + du_j/dx_i).
c
c    eps : Resolved-scale dissipation rate
c    uu  : eps for the u component
c    vv  : eps for the v component
c    ww  : eps for the w component
c
      subroutine  sub_eps3 (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uav, vav,
     o                  uu, vv, ww, uv, vw, wu,
     o                  eps )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny), fm(mx,mz,ny)
      dimension  gam(mz), fwu(mz), fvw(mz), flm(mx,ny)
      dimension  uav(mz), vav(mz)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny), ww(mx,mz,ny)
      dimension  uv(mx,mz,ny), vw(mx,mz,ny), wu(mx,mz,ny)
      dimension  eps(mx,mz,ny)
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      anu  = 1.5e-5
      cel  = 1.0/( 0.1*(dx*dy*dz)**(1.0/3.0) )
c
      do k = 1,nz+1
        uav(k) = 0.0
        vav(k) = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          uav(k) = uav(k) +u (i,k,j)
          vav(k) = vav(k) +v (i,k,j)
        end do
        end do
        uav(k) = uav(k) * rsum
        vav(k) = vav(k) * rsum
      end do
c
      do j = 1,ny-1
      do k = 1,nz
        gamk = gam(k)
      do i = 1,nx-1
        f0   = 2.0    *( gamk*fm(i,k,j) +anu )
        sub  = 2.0/3.0*(      fm(i,k,j) *cel )**2
c
        uu(i,k,j) =  f0  *( u (i+1, k , j )-u (i,k,j) ) / dx - sub
        vv(i,k,j) =  f0  *( v ( i , k ,j+1)-v (i,k,j) ) / dy - sub
        ww(i,k,j) =  f0  *( w ( i ,k+1, j )-w (i,k,j) ) / dz - sub
      end do
      end do
      end do
c
      do j = 2,ny
      do k = 1,nz
        gamk = gam(k)
c
        m    = k +1
        gamm = 0.5*( gam(m)+gam(m-1) )
        f11  = fwu(m)
        f22  = fvw(m)
      do i = 2,nx
        f0   = 0.25*gamk*( fm( i , k , j )+fm(i-1, k , j )
     :                    +fm( i , k ,j-1)+fm(i-1, k ,j-1) ) +anu
c
        uv(i,k,j) =  f0*( ( u (i,k,j)-u ( i , k ,j-1) ) / dy
     :                   +( v (i,k,j)-v (i-1, k , j ) ) / dx )
c
        f1   = 0.25*gamm*( fm( i , m , j )+fm(i-1, m , j )
     :                    +fm( i ,m-1, j )+fm(i-1,m-1, j ) ) +anu
        f2   = 0.25*gamm*( fm( i , m , j )+fm( i , m ,j-1)
     :                    +fm( i ,m-1, j )+fm( i ,m-1,j-1) ) +anu
c
        wu(i,m,j) =  f1*( ( u (i,m,j)-u ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w (i-1, m , j ) ) / dx )
     :              +f11
        vw(i,m,j) =  f2*( ( v (i,m,j)-v ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w ( i , m ,j-1) ) / dy )
     :              +f22
      end do
      end do
      end do
c
c  ***  Boundary condition  ***
      do j = 2,ny
      do i = 2,nx
        wu(i,1,j) = -0.5*( flm(i,j)+flm(i-1, j ) )*u (i,1,j)
        vw(i,1,j) = -0.5*( flm(i,j)+flm( i ,j-1) )*v (i,1,j)
c?      wu(i,1,j) =  0.0
c?      vw(i,1,j) =  0.0
      end do
      end do
c
      do j = ny-1,2,-1
      do k = 1,nz
      do i = nx-1,2,-1
        uu(i,k,j) =  -( u ( i , k , j )-uav(k) )
     :             *( ( uu( i , k , j )-uu(i-1, k , j ) ) / dx
     :               +( uv( i , k ,j+1)-uv( i , k , j ) ) / dy
     :               +( wu( i ,k+1, j )-wu( i , k , j ) ) / dz )
        vv(i,k,j) =  -( v ( i , k , j )-vav(k) )
     :             *( ( uv(i+1, k , j )-uv( i , k , j ) ) / dx
     :               +( vv( i , k , j )-vv( i , k ,j-1) ) / dy
     :               +( vw( i ,k+1, j )-vw( i , k , j ) ) / dz )
      end do
      end do
      end do
c
c  ***  Boundary condition  ***
      call sub_bc ( mx, mz, nx, nz, ny, uu )
      call sub_bc ( mx, mz, nx, nz, ny, vv )
c
      do j = 2,ny-1
      do k = nz+1,2,-1
      do i = 2,nx-1
        ww(i,k,j) =  -  w ( i , k , j )
     :             *( ( wu(i+1, k , j )-wu( i , k , j ) ) / dx
     :               +( vw( i , k ,j+1)-vw( i , k , j ) ) / dy
     :               +( ww( i , k , j )-ww( i ,k-1, j ) ) / dz )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        ww(i,1,j) = 0.0
      end do
      end do
c
      do j = 2,ny-1
      do k = 1,nz
      do i = 2,nx-1
        uu (i,k,j) = 0.5*( uu(i+1, k , j )+uu( i , k , j ) )
        vv (i,k,j) = 0.5*( vv( i , k ,j+1)+vv( i , k , j ) )
        ww (i,k,j) = 0.5*( ww( i ,k+1, j )+ww( i , k , j ) )
        eps(i,k,j) = uu(i,k,j) +vv(i,k,j) +ww(i,k,j)
      end do
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, uu  )
      call sub_bc ( mx, mz, nx, nz, ny, vv  )
      call sub_bc ( mx, mz, nx, nz, ny, ww  )
      call sub_bc ( mx, mz, nx, nz, ny, eps )
c
      return
      end
