c **********************************************************************
c *   Turbulent fluxes of momentum                                     *
c *                                                                    *
c *   # This is adapted from src/flux_m.f.                             *
c *   # sgs : = 0.0, resolved-scale fluxes; = 1.0, total fluxes        *
c **********************************************************************
c
      subroutine  sub_flux_m ( sgs,
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uav, vav,
     o                  uu, vv, ww, uv, vw, wu )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny), fm(mx,mz,ny)
      dimension  gam(mz), fwu(mz), fvw(mz), flm(mx,ny)
      dimension  uav(mz), vav(mz)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny), ww(mx,mz,ny)
      dimension  uv(mx,mz,ny), vw(mx,mz,ny), wu(mx,mz,ny)
c
      if ( sgs*(sgs-1.0) .ne. 0.0 ) stop 'Error in flux_m'
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      anu  = sgs*1.5e-5
      cel  = sgs/( 0.1*(dx*dy*dz)**(1.0/3.0) )
c
      do k = 1,nz+1
        uav(k) = 0.0
        vav(k) = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          uav(k) = uav(k) +u (i,k,j)
          vav(k) = vav(k) +v (i,k,j)
        end do
        end do
        uav(k) = uav(k) * rsum
        vav(k) = vav(k) * rsum
      end do
c
      do j = 1,ny-1
      do k = 1,nz
        gamk = sgs*gam(k)
      do i = 1,nx-1
        f0   = 2.0    *( gamk*fm(i,k,j) +anu )
        sub  = 2.0/3.0*(      fm(i,k,j) *cel )**2
c
        uu(i,k,j) =  0.25*( u (i+1, k , j )+u (i,k,j)-2.0*uav(k) )**2
     :              -f0  *( u (i+1, k , j )-u (i,k,j) ) / dx
     :              +sub
        vv(i,k,j) =  0.25*( v ( i , k ,j+1)+v (i,k,j)-2.0*vav(k) )**2
     :              -f0  *( v ( i , k ,j+1)-v (i,k,j) ) / dy
     :              +sub
        ww(i,k,j) =  0.25*( w ( i ,k+1, j )+w (i,k,j) )**2
     :              -f0  *( w ( i ,k+1, j )-w (i,k,j) ) / dz
     :              +sub
      end do
      end do
      end do
c
      do j = 2,ny
      do k = 1,nz
        gamk = sgs*gam(k)
c
        m    = k +1
        gamm = sgs*0.5*( gam(m)+gam(m-1) )
        f11  = sgs*fwu(m)
        f22  = sgs*fvw(m)
      do i = 2,nx
        f0   = 0.25*gamk*( fm( i , k , j )+fm(i-1, k , j )
     :                    +fm( i , k ,j-1)+fm(i-1, k ,j-1) ) +anu
c
        uv(i,k,j) =  0.25*( u (i,k,j)+u ( i , k ,j-1)-2.0*uav(k) )
     :                   *( v (i,k,j)+v (i-1, k , j )-2.0*vav(k) )
     :              -f0*( ( u (i,k,j)-u ( i , k ,j-1) ) / dy
     :                   +( v (i,k,j)-v (i-1, k , j ) ) / dx )
c
        f1   = 0.25*gamm*( fm( i , m , j )+fm(i-1, m , j )
     :                    +fm( i ,m-1, j )+fm(i-1,m-1, j ) ) +anu
        f2   = 0.25*gamm*( fm( i , m , j )+fm( i , m ,j-1)
     :                    +fm( i ,m-1, j )+fm( i ,m-1,j-1) ) +anu
c
        wu(i,m,j) =  0.25*( u (i,m,j)+u ( i ,m-1, j )-uav(m)-uav(m-1) )
     :                   *( w (i,m,j)+w (i-1, m , j ) )
     :              -f1*( ( u (i,m,j)-u ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w (i-1, m , j ) ) / dx )
     :              -f11
        vw(i,m,j) =  0.25*( v (i,m,j)+v ( i ,m-1, j )-vav(m)-vav(m-1) )
     :                   *( w (i,m,j)+w ( i , m ,j-1) )
     :              -f2*( ( v (i,m,j)-v ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w ( i , m ,j-1) ) / dy )
     :              -f22
      end do
      end do
      end do
c
c  ***  Lower boundary condition  ***
      do j = 2,ny-1
      do i = 2,nx-1
        wu(i,1,j) = sgs*0.5*( flm(i,j)+flm(i-1, j ) )*u (i,1,j)
        vw(i,1,j) = sgs*0.5*( flm(i,j)+flm( i ,j-1) )*v (i,1,j)
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, uu )
      call sub_bc ( mx, mz, nx, nz, ny, vv )
      call sub_bc ( mx, mz, nx, nz, ny, ww )
      call sub_bc ( mx, mz, nx, nz, ny, uv )
      call sub_bc ( mx, mz, nx, nz, ny, vw )
      call sub_bc ( mx, mz, nx, nz, ny, wu )
c
      return
      end
