c **********************************************************************
c *   Fluxes for nondiagonal elements of Reynolds stress               *
c *   1. Vertical flux of uv for <uv>                                  *
c *   2. Horizontal fluxes of ww and pressure for <uw> and <vw>        *
c *                                                                    *
c *   # Subgrid-scale fluxes are neglected.                            *
c **********************************************************************
c
      subroutine  sub_flux_tp4non (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, pd,
     w                  uav, vav,
     o                  uv, wu, vw, uu, vv )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny), fm(mx,mz,ny)
      dimension  pd(mx,mz,ny)
      dimension  uav(mz), vav(mz)
      dimension  uv(mx,mz,ny), wu(mx,mz,ny), vw(mx,mz,ny)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny)
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      anu  = 1.5e-5
      cel  = 1.0/( 0.1*(dx*dy*dz)**(1.0/3.0) )
c
      do k = 1,nz+1
        uav(k) = 0.0
        vav(k) = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          uav(k) = uav(k) +u (i,k,j)
          vav(k) = vav(k) +v (i,k,j)
        end do
        end do
        uav(k) = uav(k) * rsum
        vav(k) = vav(k) * rsum
      end do
c
      do j = 1,ny-1
      do k = 1,nz
      do i = 1,nx-1
        uu(i,k,j) =   0.25 *( u (i+1, k , j )+u (i,k,j)-2.0*uav(k) )
     :                     *( v ( i , k ,j+1)+v (i,k,j)-2.0*vav(k) )
        vv(i,k,j) =   0.25 *( w ( i ,k+1, j )+w (i,k,j) )**2
     :             +          pd( i , k , j )
     :             -2.0/3.0*( fm( i , k , j )*cel )**2
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 1,nz
        m    = k +1
      do i = 2,nx-1
        wu(i,k,j) = 0.5*( vv(i,k,j)+vv(i-1, k , j ) )
     :                 *( u (i,k,j)-uav(k) )
        vw(i,k,j) = 0.5*( vv(i,k,j)+vv( i , k ,j-1) )
     :                 *( v (i,k,j)-vav(k) )
        uv(i,m,j) = 0.5*( uu(i,m,j)+uu( i ,m-1, j ) )
     :                 *  w (i,m,j)
      end do
      end do
      end do
c
c  ***  Boundary condition  ***
      do j = 1,ny
      do i = 1,nx
        uv(i,   1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, uv )
      call sub_bc ( mx, mz, nx, nz, ny, wu )
      call sub_bc ( mx, mz, nx, nz, ny, vw )
c
      return
      end
