c **********************************************************************
c *   Turbulent fluxes of virtual potential temperature                *
c *                                                                    *
c *   # This is adapted from src/flux_s.f.                             *
c *   # sgs : = 0.0, resolved-scale fluxes; = 1.0, total fluxes        *
c **********************************************************************
c
      subroutine  sub_flux_v ( sgs,
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref, psf,
     i                  u, v, w, t, q, ql, fh, vt, vq, flt, flq,
     w                  uav, vav, tav,
     o                  uu, vv, ww, tv )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny)
      dimension  t (mx,mz,ny), q (mx,mz,ny), ql(mx,mz,ny)
      dimension  fh(mx,mz,ny), vt(mx,mz,ny), vq(mx,mz,ny)
      dimension  flt(mx,ny), flq(mx,ny)
      dimension  uav(mz), vav(mz), tav(mz)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny), ww(mx,mz,ny)
      dimension  tv(mx,mz,ny)
c
      if ( sgs*(sgs-1.0) .ne. 0.0 ) stop 'Error in flux_v'
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      qnu  = sgs*2.1e-5
      gtr  = 9.81/tref
c
c  ***  Correctly, pibm needs to be adjusted (see src/initial.f).  ***
      pibm = 1004.0*( psf/1000.0 )**( 287.0/1004.0 )
c
      call sub_bc ( mx, mz, nx, nz, ny, ql )
      call sub_bc ( mx, mz, nx, nz, ny, vt )
      call sub_bc ( mx, mz, nx, nz, ny, vq )
c
      do j = 1,ny
      do k = 1,nz
        pp = 2.5e6/( pibm-gtr*dz*(k-0.5) )
      do i = 1,nx
        tv(i,k,j) = ( t (i,k,j) +tref +pp*ql(i,k,j) )
     :             *( 1.0 +0.61*q (i,k,j) -1.61*ql(i,k,j) ) -tref
      end do
      end do
      end do
c
      do k = 1,nz+1
        uav(k) = 0.0
        vav(k) = 0.0
        tav(k) = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          uav(k) = uav(k) +u (i,k,j)
          vav(k) = vav(k) +v (i,k,j)
          tav(k) = tav(k) +tv(i,k,j)
        end do
        end do
        uav(k) = uav(k) * rsum
        vav(k) = vav(k) * rsum
        tav(k) = tav(k) * rsum
      end do
c
      do j = 2,ny
      do k = 1,nz
      do i = 2,nx
        f1  = sgs* 0.5*( fh(i,k,j)+fh(i-1, k , j ) ) +qnu
        f1t = f1 * 0.5*( vt( i ,k,j)+0.61*  q ( i ,k,j)+1.0
     :                  +vt(i-1,k,j)+0.61*  q (i-1,k,j)+1.0    )
        f1q = f1 * 0.5*( vq( i ,k,j)+0.61*( t ( i ,k,j)+tref )
     :                  +vq(i-1,k,j)+0.61*( t (i-1,k,j)+tref ) )
c
        f2  = sgs* 0.5*( fh(i,k,j)+fh( i , k ,j-1) ) +qnu
        f2t = f2 * 0.5*( vt(i,k, j )+0.61*  q (i,k, j )+1.0
     :                  +vt(i,k,j-1)+0.61*  q (i,k,j-1)+1.0    )
        f2q = f2 * 0.5*( vq(i,k, j )+0.61*( t (i,k, j )+tref )
     :                  +vq(i,k,j-1)+0.61*( t (i,k,j-1)+tref ) )
c
        uu(i,k,j) =  0.5*( tv(i,k,j)+tv(i-1, k , j )-2.0*tav(k) )
     :                  *( u (i,k,j)                -    uav(k) )
     :              -f1t*( t (i,k,j)-t (i-1, k , j ) ) / dx
     :              -f1q*( q (i,k,j)-q (i-1, k , j ) ) / dx
        vv(i,k,j) =  0.5*( tv(i,k,j)+tv( i , k ,j-1)-2.0*tav(k) )
     :                  *( v (i,k,j)                -    vav(k) )
     :              -f2t*( t (i,k,j)-t ( i , k ,j-1) ) / dy
     :              -f2q*( q (i,k,j)-q ( i , k ,j-1) ) / dy
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 2,nz+1
      do i = 1,mx
        f1  = sgs* 0.5*( fh(i,k,j)+fh( i ,k-1, j ) ) +qnu
        f1t = f1 * 0.5*( vt(i, k ,j)+0.61*  q (i, k ,j)+1.0
     :                  +vt(i,k-1,j)+0.61*  q (i,k-1,j)+1.0    )
        f1q = f1 * 0.5*( vq(i, k ,j)+0.61*( t (i, k ,j)+tref )
     :                  +vq(i,k-1,j)+0.61*( t (i,k-1,j)+tref ) )
c
        ww(i,k,j) =  0.5*( tv(i,k,j)+tv( i ,k-1, j )-tav(k)-tav(k-1) )
     :                  *  w (i,k,j)
     :              -f1t*( t (i,k,j)-t ( i ,k-1, j ) ) / dz
     :              -f1q*( q (i,k,j)-q ( i ,k-1, j ) ) / dz
      end do
      end do
      end do
c
c  ***  Lower boundary condition  ***
      do j = 2,ny-1
      do i = 2,nx-1
        ww(i,1,j) = sgs*( vt(i,1,j)+0.61*  q (i,1,j)+1.0    )*flt(i,j)
     :             +sgs*( vq(i,1,j)+0.61*( t (i,1,j)+tref ) )*flq(i,j)
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, uu )
      call sub_bc ( mx, mz, nx, nz, ny, vv )
      call sub_bc ( mx, mz, nx, nz, ny, ww )
c
      return
      end
