c **********************************************************************
c *   Several terms of the vorticity equation in the y direction       *
c *                                                                    *
c *   # sub_strtil_y  calculates the stretching and tilting terms      *
c *                   fs = 2*omega*sin( phi )              (s^(-1))    *
c *                   fc = 2*omega*cos( phi )              (s^(-1))    *
c *   # sub_tilccf_y  calculates the tilting term                      *
c *                   due to centrifugal (and Coriolis) force(s)       *
c *                   rc = radius from the typhoon center  (m)         *
c *                   NOTE: If fs is considered in sub_strtil_y,       *
c *                         fs here has to be set to zero.             *
c *   # sub_barocli_y calculates the baroclinic production term        *
c *   # sub_vordif_y  calculates the turbulent diffusion term          *
c *   # sub_verttp_y  calculates the vertical transport term           *
c **********************************************************************
c
      subroutine  sub_strtil_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, fs, fc,
     i                  v, zx, zy, zz,
     o                  str, tilx, tilz, wok )
c
      include  "../src/Implicit.h"
c
      dimension  v (mx,mz,ny), zx(mx,mz,ny), zy(mx,mz,ny), zz(mx,mz,ny)
      dimension  str(mx,mz,ny), tilx(mx,mz,ny), tilz(mx,mz,ny)
      dimension  wok(mx,mz,ny)
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        wok (i,k,j) = 0.25*( zy(i+1, k , j )+zy( i , k , j )+2.0*fc )
     :                    *( v ( i , k ,j+1)-v ( i , k , j )
     :                      +v ( i ,k-1,j+1)-v ( i ,k-1, j ) ) / dy
c
        tilx(i,k,j) = 0.25*( zx( i , k , j )+zx(i-1, k , j ) )
     :                    *( v ( i , k , j )-v (i-1, k , j )
     :                      +v ( i ,k-1, j )-v (i-1,k-1, j ) ) / dx
        tilz(i,k,j) = 0.25*( zz( i , k , j )+zz( i ,k-1, j )+2.0*fs )
     :                    *( v ( i , k , j )-v ( i ,k-1, j )
     :                      +v (i-1, k , j )-v (i-1,k-1, j ) ) / dz
      end do
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, wok  )
      call sub_bc ( mx, mz, nx, nz, ny, tilx )
      call sub_bc ( mx, mz, nx, nz, ny, tilz )
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        str (i,k,j) = 0.5*( wok (i,k,j)+wok (i-1, k , j ) )
        tilx(i,k,j) = 0.5*( tilx(i,k,j)+tilx( i , k ,j+1) )
        tilz(i,k,j) = 0.5*( tilz(i,k,j)+tilz( i , k ,j+1) )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        str (i,1,j) = 0.0
        tilx(i,1,j) = 0.0
        tilz(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, str  )
      call sub_bc ( mx, mz, nx, nz, ny, tilx )
      call sub_bc ( mx, mz, nx, nz, ny, tilz )
c
      return
      end
c
      subroutine  sub_tilccf_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, fs, rc,
     i                  v,
     o                  ccf, wok )
c
      include  "../src/Implicit.h"
c
      dimension  v (mx,mz,ny)
      dimension  ccf(mx,mz,ny), wok(mx,mz,ny)
c
      if ( rc .le. 0.0 ) then
        rrc = 0.0
      else
        rrc = 1.0 / rc
      end if
c
      do j = 2,ny
      do k = 2,nz
c?    do i = 1,nx-1
c?      wok(i,k,j) =     ( ( v ( i ,k,j)+v ( i ,k-1,j) ) * rrc + fs )
c?   :              *      ( v ( i ,k,j)-v ( i ,k-1,j) ) / dz
      do i = 2,nx-1
        wok(i,k,j) = ( 0.5*( v ( i ,k,j)+v ( i ,k-1,j)
     :                      +v (i-1,k,j)+v (i-1,k-1,j) ) * rrc + fs )
     :              *  0.5*( v ( i ,k,j)-v ( i ,k-1,j)
     :                      +v (i-1,k,j)-v (i-1,k-1,j) ) / dz
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
c?      ccf(i,k,j) = 0.25*( wok( i , k , j )+wok( i , k ,j+1)
c?   :                     +wok(i-1, k , j )+wok(i-1, k ,j+1) )
        ccf(i,k,j) = 0.5 *( wok( i , k , j )+wok( i , k ,j+1) )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        ccf(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, ccf )
c
      return
      end
c
      subroutine  sub_barocli_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref, psf,
     i                  t, q, ql,
     o                  bar, wok )
c
      include  "../src/Implicit.h"
c
      dimension  t (mx,mz,ny), q (mx,mz,ny), ql(mx,mz,ny)
      dimension  bar(mx,mz,ny), wok(mx,mz,ny)
c
      gtr  = 9.81/tref
c
c  ***  Correctly, pibm needs to be adjusted (see src/initial.f).  ***
      pibm = 1004.0*( psf/1000.0 )**( 287.0/1004.0 )
c
      call sub_bc ( mx, mz, nx, nz, ny, ql )
c
      do j = 1,ny
      do k = 1,nz
        pp = 2.5e6/( pibm-gtr*dz*(k-0.5) )
      do i = 1,nx
        wok(i,k,j) = ( t (i,k,j) +tref +pp*ql(i,k,j) )
     :              *( 1.0 +0.61*q (i,k,j) -1.61*ql(i,k,j) ) -tref
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        bar(i,k,j) = -0.5*gtr*( wok( i , k ,j)-wok(i-1, k ,j)
     :                         +wok( i ,k-1,j)-wok(i-1,k-1,j) ) / dx
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        bar(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, bar )
c
      return
      end
c
      subroutine  sub_vordif_y ( wcon,
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uu, vv, ww, uv, vw, wu,
     o                  dif )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny), fm(mx,mz,ny)
      dimension  gam(mz), fwu(mz), fvw(mz), flm(mx,ny)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny), ww(mx,mz,ny)
      dimension  uv(mx,mz,ny), vw(mx,mz,ny), wu(mx,mz,ny)
      dimension  dif(mx,mz,ny)
c
      if ( wcon*(wcon-1.0) .ne. 0.0 ) stop 'Error in vordif_y'
c
      anu  = 1.5e-5
c
c  ***  The term of TKE is eliminated by differential operation. ***
      do j = 1,ny-1
      do k = 1,nz
        gamk = gam(k)
      do i = 1,nx-1
        f0   = 2.0    *( gamk*fm(i,k,j) +anu )
c
        uu(i,k,j) =  f0  *( u (i+1, k , j )-u (i,k,j) ) / dx
        vv(i,k,j) =  f0  *( v ( i , k ,j+1)-v (i,k,j) ) / dy
        ww(i,k,j) =  f0  *( w ( i ,k+1, j )-w (i,k,j) ) / dz
      end do
      end do
      end do
c
      do j = 2,ny
      do k = 1,nz
        gamk = gam(k)
c
        m    = k +1
        gamm = 0.5*( gam(m)+gam(m-1) )
        f11  = fwu(m)
        f22  = fvw(m)
      do i = 2,nx
        f0   = 0.25*gamk*( fm( i , k , j )+fm(i-1, k , j )
     :                    +fm( i , k ,j-1)+fm(i-1, k ,j-1) ) +anu
c
        uv(i,k,j) =  f0*( ( u (i,k,j)-u ( i , k ,j-1) ) / dy
     :                   +( v (i,k,j)-v (i-1, k , j ) ) / dx )
c
        f1   = 0.25*gamm*( fm( i , m , j )+fm(i-1, m , j )
     :                    +fm( i ,m-1, j )+fm(i-1,m-1, j ) ) +anu
        f2   = 0.25*gamm*( fm( i , m , j )+fm( i , m ,j-1)
     :                    +fm( i ,m-1, j )+fm( i ,m-1,j-1) ) +anu
c
        wu(i,m,j) =  f1*( ( u (i,m,j)-u ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w (i-1, m , j ) ) / dx )
     :              +f11
        vw(i,m,j) =  f2*( ( v (i,m,j)-v ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w ( i , m ,j-1) ) / dy )
     :              +f22
      end do
      end do
      end do
c
c  ***  Lower boundary condition  ***
      do j = 2,ny
      do i = 2,nx
        wu(i,1,j) = -0.5*( flm(i,j)+flm(i-1, j ) )*u (i,1,j)
        vw(i,1,j) = -0.5*( flm(i,j)+flm( i ,j-1) )*v (i,1,j)
      end do
      end do
c
      do j = ny-1,2,-1
      do k = nz,1,-1
        m    = k +1
      do i = nx-1,2,-1
        uu(i,k,j) = ( uu( i , k , j )-uu(i-1, k , j ) ) / dx
     :             +( uv( i , k ,j+1)-uv( i , k , j ) ) / dy
     :             +( wu( i ,k+1, j )-wu( i , k , j ) ) / dz
        ww(i,m,j) = ( wu(i+1, m , j )-wu( i , m , j ) ) / dx
     :             +( vw( i , m ,j+1)-vw( i , m , j ) ) / dy
     :             +( ww( i , m , j )-ww( i ,m-1, j ) ) / dz
      end do
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, ww )
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        dif(i,k,j) =      ( uu(i,k,j)-uu( i ,k-1, j ) ) / dz
     :              -wcon*( ww(i,k,j)-ww(i-1, k , j ) ) / dx
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        dif(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, dif )
c
      return
      end
c
      subroutine  sub_verttp_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  w, zy,
     o                  vtp, wok )
c
      include  "../src/Implicit.h"
c
      dimension  w (mx,mz,ny), zy(mx,mz,ny)
      dimension  vtp(mx,mz,ny), wok(mx,mz,ny)
c
      do j = 2,ny-1
c?    do k = 1,nz+1
      do k = 1,nz
      do i = 2,nx-1
c?      wok(i,k,j) = -0.5  *( w (i, k ,j)+w (i-1, k ,j) )*zy(i,k,j)
        wok(i,k,j) = -0.125*( w (i,k+1,j)+w (i-1,k+1,j)
     :                       +w (i, k ,j)+w (i-1, k ,j) )
     :                     *( zy(i,k+1,j)+zy( i , k ,j) )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
c?      vtp(i,k,j) = 0.5*( wok(i,k+1,j)-wok(i,k-1,j) ) / dz
        vtp(i,k,j) =     ( wok(i, k ,j)-wok(i,k-1,j) ) / dz
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        vtp(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, vtp )
c
      return
      end
