c **********************************************************************
c *   Several terms of the vorticity equation in the z direction       *
c *                                                                    *
c *   # sub_strtil_z  calculates the stretching and tilting terms      *
c *                   fs = 2*omega*sin( phi )              (s^(-1))    *
c *                   fc = 2*omega*cos( phi )              (s^(-1))    *
c *   # sub_strccf_z  calculates the stretching term                   *
c *                   due to centrifugal (and Coriolis) force(s)       *
c *                   rc = radius from the typhoon center  (m)         *
c *                   NOTE: If fs is considered in sub_strtil_z,       *
c *                         fs here has to be set to zero.             *
c *   # sub_vordif_z  calculates the turbulent diffusion term          *
c *   # sub_verttp_z  calculates the vertical transport term           *
c **********************************************************************
c
      subroutine  sub_strtil_z (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, fs, fc,
     i                  w, zx, zy, zz,
     o                  str, tilx, tily, wok )
c
      include  "../src/Implicit.h"
c
      dimension  w (mx,mz,ny), zx(mx,mz,ny), zy(mx,mz,ny), zz(mx,mz,ny)
      dimension  str(mx,mz,ny), tilx(mx,mz,ny), tily(mx,mz,ny)
      dimension  wok(mx,mz,ny)
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        wok (i,k,j) = 0.25*( zz(i+1, k , j )+zz( i , k , j )+2.0*fs )
     :                    *( w ( i ,k+1, j )-w ( i , k , j )
     :                      +w ( i ,k+1,j-1)-w ( i , k ,j-1) ) / dz
c
        tilx(i,k,j) = 0.25*( zx( i , k , j )+zx(i-1, k , j ) )
     :                    *( w ( i , k , j )-w (i-1, k , j )
     :                      +w ( i , k ,j-1)-w (i-1, k ,j-1) ) / dx
        tily(i,k,j) = 0.25*( zy( i , k , j )+zy( i , k ,j-1)+2.0*fc )
     :                    *( w ( i , k , j )-w ( i , k ,j-1)
     :                      +w (i-1, k , j )-w (i-1, k ,j-1) ) / dy
      end do
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, wok  )
      call sub_bc ( mx, mz, nx, nz, ny, tilx )
      call sub_bc ( mx, mz, nx, nz, ny, tily )
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        str (i,k,j) = 0.5*( wok (i,k,j)+wok (i-1, k , j ) )
        tilx(i,k,j) = 0.5*( tilx(i,k,j)+tilx( i ,k+1, j ) )
        tily(i,k,j) = 0.5*( tily(i,k,j)+tily( i ,k+1, j ) )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        str (i,1,j) = 0.0
        tilx(i,1,j) = 0.0
        tily(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, str  )
      call sub_bc ( mx, mz, nx, nz, ny, tilx )
      call sub_bc ( mx, mz, nx, nz, ny, tily )
c
      return
      end
c
      subroutine  sub_strccf_z (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, fs, rc,
     i                  u, v, w,
     o                  ccf, wok )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny)
      dimension  ccf(mx,mz,ny), wok(mx,mz,ny)
c
      if ( rc .le. 0.0 ) then
        rrc = 0.0
      else
        rrc = 1.0 / rc
      end if
c
      do j = 1,ny-1
      do k = 2,nz
      do i = 2,nx-1
        wok(i,k,j) = ( 0.25*( v ( i ,k,j+1)+v ( i ,k, j )
     :                       +v (i-1,k,j+1)+v (i-1,k, j ) ) * rrc + fs )
     :              *  0.5 *( w ( i ,k+1,j)-w ( i ,k, j )
     :                       +w (i-1,k+1,j)-w (i-1,k, j ) ) / dz
     :              -                       u ( i ,k, j )   * rrc
     :              *  0.5 *( v ( i ,k,j+1)-v (i-1,k, j+1)
     :                       +v ( i ,k, j )-v (i-1,k, j ) ) / dx
     :              -  0.25*( v ( i ,k,j+1)+v ( i ,k, j )
     :                       +v (i-1,k,j+1)+v (i-1,k, j ) ) * rrc
     :              *  0.5 *( v ( i ,k,j+1)-v ( i ,k, j )
     :                       +v (i-1,k,j+1)-v (i-1,k, j ) ) / dy
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        ccf(i,k,j) = 0.5 *( wok( i , k , j )+wok( i , k ,j-1) )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        ccf(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, ccf )
c
      return
      end
c
      subroutine  sub_vordif_z ( wcon,
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uu, vv, ww, uv, vw, wu,
     o                  dif )
c
      include  "../src/Implicit.h"
c
      dimension  u (mx,mz,ny), v (mx,mz,ny), w (mx,mz,ny), fm(mx,mz,ny)
      dimension  gam(mz), fwu(mz), fvw(mz), flm(mx,ny)
      dimension  uu(mx,mz,ny), vv(mx,mz,ny), ww(mx,mz,ny)
      dimension  uv(mx,mz,ny), vw(mx,mz,ny), wu(mx,mz,ny)
      dimension  dif(mx,mz,ny)
c
      if ( wcon*(wcon-1.0) .ne. 0.0 ) stop 'Error in vordif_z'
c
      anu  = 1.5e-5
c
c  ***  The term of TKE is eliminated by differential operation. ***
      do j = 1,ny-1
      do k = 1,nz
        gamk = gam(k)
      do i = 1,nx-1
        f0   = 2.0    *( gamk*fm(i,k,j) +anu )
c
        uu(i,k,j) =  f0  *( u (i+1, k , j )-u (i,k,j) ) / dx
        vv(i,k,j) =  f0  *( v ( i , k ,j+1)-v (i,k,j) ) / dy
        ww(i,k,j) =  f0  *( w ( i ,k+1, j )-w (i,k,j) ) / dz
      end do
      end do
      end do
c
      do j = 2,ny
      do k = 1,nz
        gamk = gam(k)
c
        m    = k +1
        gamm = 0.5*( gam(m)+gam(m-1) )
        f11  = fwu(m)
        f22  = fvw(m)
      do i = 2,nx
        f0   = 0.25*gamk*( fm( i , k , j )+fm(i-1, k , j )
     :                    +fm( i , k ,j-1)+fm(i-1, k ,j-1) ) +anu
c
        uv(i,k,j) =  f0*( ( u (i,k,j)-u ( i , k ,j-1) ) / dy
     :                   +( v (i,k,j)-v (i-1, k , j ) ) / dx )
c
        f1   = 0.25*gamm*( fm( i , m , j )+fm(i-1, m , j )
     :                    +fm( i ,m-1, j )+fm(i-1,m-1, j ) ) +anu
        f2   = 0.25*gamm*( fm( i , m , j )+fm( i , m ,j-1)
     :                    +fm( i ,m-1, j )+fm( i ,m-1,j-1) ) +anu
c
        wu(i,m,j) =  f1*( ( u (i,m,j)-u ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w (i-1, m , j ) ) / dx )
     :              +f11
        vw(i,m,j) =  f2*( ( v (i,m,j)-v ( i ,m-1, j ) ) / dz
     :                   +( w (i,m,j)-w ( i , m ,j-1) ) / dy )
     :              +f22
      end do
      end do
      end do
c
c  ***  Lower boundary condition  ***
      do j = 2,ny
      do i = 2,nx
        wu(i,1,j) = -0.5*( flm(i,j)+flm(i-1, j ) )*u (i,1,j)
        vw(i,1,j) = -0.5*( flm(i,j)+flm( i ,j-1) )*v (i,1,j)
      end do
      end do
c
      do j = ny-1,2,-1
      do k = nz,1,-1
      do i = nx-1,2,-1
        uu(i,k,j) = ( uu( i , k , j )-uu(i-1, k , j ) ) / dx
     :             +( uv( i , k ,j+1)-uv( i , k , j ) ) / dy
     :             +( wu( i ,k+1, j )-wu( i , k , j ) ) / dz
        vv(i,k,j) = ( uv(i+1, k , j )-uv( i , k , j ) ) / dx
     :             +( vv( i , k , j )-vv( i , k ,j-1) ) / dy
     :             +( vw( i ,k+1, j )-vw( i , k , j ) ) / dz
      end do
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, uu )
      call sub_bc ( mx, mz, nx, nz, ny, vv )
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        dif(i,k,j) = ( vv(i,k,j)-vv(i-1, k , j ) ) / dx
     :              -( uu(i,k,j)-uu( i , k ,j-1) ) / dy
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        dif(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, dif )
c
      return
      end
c
      subroutine  sub_verttp_z (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  w, zz,
     o                  vtp, wok )
c
      include  "../src/Implicit.h"
c
      dimension  w (mx,mz,ny), zz(mx,mz,ny)
      dimension  vtp(mx,mz,ny), wok(mx,mz,ny)
c
      do j = 2,ny-1
      do k = 2,nz+1
      do i = 2,nx-1
        wok(i,k,j) = -0.125*( w (i,k, j )+w (i-1, k , j )
     :                       +w (i,k,j-1)+w (i-1, k ,j-1) )
     :                     *( zz(i,k, j )+zz( i ,k-1, j ) )
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 2,nz
      do i = 2,nx-1
        vtp(i,k,j) = ( wok(i,k+1,j)-wok(i,k,j) ) / dz
      end do
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        vtp(i,1,j) = 0.0
      end do
      end do
c
      call sub_bc ( mx, mz, nx, nz, ny, vtp )
c
      return
      end
