c **********************************************************************
c *   Calculates turbulence kinetic energy                             *
c *                                                                    *
c *   Input parameters:                                                *
c *     r_num         : Run number                      (Run.Restart)  *
c *                   : For example, 01.01                             *
c *     irec          : Record number to be extracted                  *
c *                                                                    *
c *                                   May/2010  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_bc.f"
      include  "sub_flux_m.f"
      include  "sub_data_dir.f"
c
      include  "../src/Implicit.h"
c
      parameter ( mx=502, my=502, mz=201 )
      parameter ( mip=8, one=1.0 )
c
      character (len=5) :: r_num
      character (len=4) :: f_name(mip) =
     3                 (/'u___', 'v___', 'w___',
     3                   'fm__',
     2                   'flm_',
     1                   'gam_', 'fwu_', 'fvw_'                /)
c
      dimension  u (mx,mz,my), v (mx,mz,my), w (mx,mz,my)
      dimension  fm(mx,mz,my)
      dimension  flm(mx,my)
      dimension  gam(mz), fwu(mz), fvw(mz)
c
      dimension  uav(mz), vav(mz)
      dimension  uu(mx,mz,my), vv(mx,mz,my), ww(mx,mz,my)
      dimension  uv(mx,mz,my), vw(mx,mz,my), wu(mx,mz,my)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      namelist  /post/ r_num, irec, iplane, jplane, kplane
c
      r_num    = ''
      irec     = 1
      iplane   = 0
      jplane   = 0
      kplane   = 0
c
      read (5,nml=post)
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
c
      close(10)
c
      do k = 1,lz
        gam(k) = 1.0
        fwu(k) = 0.0
        fvw(k) = 0.0
      end do
c
      do m = 1,mip
        mt = m +20
c
        call sub_data_open ( r_num,f_name(m), mt, lx,lz,ly )
c
        select case ( f_name(m) )
          case ( 'u___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, u   )
          case ( 'v___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, v   )
          case ( 'w___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, w   )
          case ( 'fm__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, fm  )
          case ( 'flm_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flm )
          case ( 'gam_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, gam )
          case ( 'fwu_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, fwu )
          case ( 'fvw_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, fvw )
        end select
      end do
c
        call sub_flux_m ( one,
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uav, vav,
     o                  uu, vv, ww, uv, vw, wu )
c
        do j = 1,ly
        do k = 1,lz
        do i = 1,lx
          uu(i,k,j) = 0.5*( uu(i,k,j)+vv(i,k,j)+ww(i,k,j) )
        end do
        end do
        end do
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
      xp   = dx*( iplane-1.5 ); if ( xp .lt. 0.0 ) xp = dx*( nx-2 )
      yp   = dy*( jplane-1.5 ); if ( yp .lt. 0.0 ) yp = dy*( ny-2 )
      zp   = dz*( kplane-0.5 ); if ( zp .lt. 0.0 ) zp = dz*( nz   )
c
      write(6,'(i5.4)') ih
      write(6,*) real(dx), real(dy), real(dz)
      write(6,*) real(xp), real(yp), real(zp)
c
      if     ( iplane .gt. 0 .and. iplane .lt. nx ) then
        write(6,*) 'y-z'
c
        i = iplane
        do k = 1,nz
        do j = 1,ny
          write(6,*) dy*(j-1.5), dz*(k-0.5), real(uu(i,k,j))
        end do
        end do
c
      elseif ( jplane .gt. 0 .and. jplane .lt. ny ) then
        write(6,*) 'x-z'
c
        j = jplane
        do k = 1,nz
        do i = 1,nx
          write(6,*) dx*(i-1.5), dz*(k-0.5), real(uu(i,k,j))
        end do
        end do
c
      elseif ( kplane .gt. 0 .and. kplane .le. nz ) then
        write(6,*) 'x-y'
c
        k = kplane
        do j = 1,ny
        do i = 1,nx
          write(6,*) dx*(i-1.5), dy*(j-1.5), real(uu(i,k,j))
        end do
        end do
      end if
c
  999 stop
      end
