c **********************************************************************
c *   Calculates variances and fluxes                                  *
c *                                                                    *
c *   Input parameters:                                                *
c *     r_num         : Run number                      (Run.Restart)  *
c *                   : For example, 01.01                             *
c *     irec          : Record number to be extracted                  *
c *                                                                    *
c *                                   Jun/2010  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_bc.f"
      include  "sub_flux_m.f"
      include  "sub_flux_v.f"
      include  "sub_ziwst.f"
      include  "sub_data_dir.f"
c
      include  "../src/Implicit.h"
c
      parameter ( mx=502, my=502, mz=201 )
      parameter ( mip=16, one=1.0 )
c
      character (len=5) :: r_num
      character (len=4) :: f_name(mip) =
     3                 (/'u___', 'v___', 'w___', 't___', 'q___',
     3                   'fm__', 'fh__',
     3                   'ql__', 'vt__', 'vq__',
     2                   'flm_', 'flt_', 'flq_',
     1                   'gam_', 'fwu_', 'fvw_'                /)
c
      dimension  u (mx,mz,my), v (mx,mz,my), w (mx,mz,my)
      dimension  t (mx,mz,my), q (mx,mz,my)
      dimension  fm(mx,mz,my), fh(mx,mz,my)
      dimension  ql(mx,mz,my), vt(mx,mz,my), vq(mx,mz,my)
      dimension  flm(mx,my), flt(mx,my), flq(mx,my)
      dimension  gam(mz), fwu(mz), fvw(mz)
c
      dimension  uav(mz), vav(mz), tav(mz)
      dimension  uu(mx,mz,my), vv(mx,mz,my), ww(mx,mz,my)
      dimension  uv(mx,mz,my), vw(mx,mz,my), wu(mx,mz,my)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      namelist  /post/ r_num, irec, ziin
c
      r_num    = ''
      irec     = 1
      ziin     = 0.0
c
      read (5,nml=post)
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
c
      close(10)
c
      do k = 1,lz
        gam(k) = 1.0
        fwu(k) = 0.0
        fvw(k) = 0.0
      end do
c
      do m = 1,mip
        mt = m +20
c
        call sub_data_open ( r_num,f_name(m), mt, lx,lz,ly )
c
        select case ( f_name(m) )
          case ( 'u___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, u   )
          case ( 'v___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, v   )
          case ( 'w___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, w   )
          case ( 't___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, t   )
          case ( 'q___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, q   )
          case ( 'fm__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, fm  )
          case ( 'fh__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, fh  )
          case ( 'ql__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, ql  )
          case ( 'vt__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, vt  )
          case ( 'vq__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, vq  )
          case ( 'flm_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flm )
          case ( 'flt_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flt )
          case ( 'flq_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flq )
          case ( 'gam_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, gam )
          case ( 'fwu_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, fwu )
          case ( 'fvw_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, fvw )
        end select
      end do
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
c
      write(6,'(i5.4)') ih
      write(6,*) dz
      write(6,*) dz*nz
      write(6,*) 'variance&flux'
c
        call sub_flux_v ( one,
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref, psf,
     i                  u, v, w, t, q, ql, fh, vt, vq, flt, flq,
     w                  uav, vav, tav,
     o                  uu, vv, ww, uv )
        call sub_ziwst ( ziin,
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref,
     i                  u, v, ww, flm,
     w                  tav,
     o                  zi, wst, ust )
c
      write(6,*) 'zi',  real(zi)
      write(6,*) 'wst', real(wst)
      write(6,*) 'ust', real(ust)
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      rnom = 1.0/wst**2
c
      do k = 1,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + 9.81/tref*ww(i,k,j)
        end do
        end do
        write(6,*) 'tw', real(ave*rsum*rnom), real(dz*(k-1))
      end do
c
        call sub_flux_m ( one,
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uav, vav,
     o                  uu, vv, ww, uv, vw, wu )
c
      do k = 1,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + uu(i,k,j)
        end do
        end do
        write(6,*) 'uu', real(ave*rsum*rnom), real(dz*(k-0.5))
      end do
c
      do k = 1,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + vv(i,k,j)
        end do
        end do
        write(6,*) 'vv', real(ave*rsum*rnom), real(dz*(k-0.5))
      end do
c
      do k = 1,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + ww(i,k,j)
        end do
        end do
        write(6,*) 'ww', real(ave*rsum*rnom), real(dz*(k-0.5))
      end do
c
      do k = 1,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + 0.5*( uu(i,k,j)+vv(i,k,j)+ww(i,k,j) )
        end do
        end do
        write(6,*) 'tke', real(ave*rsum*rnom), real(dz*(k-0.5))
      end do
c
      do k = 2,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + wu(i,k,j)
        end do
        end do
        write(6,*) 'uw', real(ave*rsum*rnom), real(dz*(k-1))
      end do
c
      do k = 2,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + vw(i,k,j)
        end do
        end do
        write(6,*) 'vw', real(ave*rsum*rnom), real(dz*(k-1))
      end do
c
      do k = 1,nz
        ave = 0.0
        do j = 2,ny-1
        do i = 2,nx-1
          ave = ave + uv(i,k,j)
        end do
        end do
        write(6,*) 'uv', real(ave*rsum*rnom), real(dz*(k-0.5))
      end do
c
  999 stop
      end
