c **********************************************************************
c *   Calculates Vorticity budgets                                     *
c *                                                                    *
c *   Input parameters:                                                *
c *     r_num         : Run number                      (Run.Restart)  *
c *                   : For example, 01.01                             *
c *     irec          : Record number to be extracted                  *
c *                                                                    *
c *                                   May/2010  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_bc.f"
      include  "sub_vor.f"
      include  "sub_vterm_y.f"
      include  "sub_data_dir.f"
c
      include  "../src/Implicit.h"
c
      parameter ( mx=502, my=502, mz=201 )
      parameter ( mip=11, one=1.0 )
c
      character (len=5) :: r_num
      character (len=4) :: f_name(mip) =
     3                 (/'u___', 'v___', 'w___', 't___', 'q___',
     3                   'fm__',
     3                   'ql__',
     2                   'flm_',
     1                   'gam_', 'fwu_', 'fvw_'                /)
c
      dimension  u (mx,mz,my), v (mx,mz,my), w (mx,mz,my)
      dimension  t (mx,mz,my), q (mx,mz,my)
      dimension  fm(mx,mz,my)
      dimension  ql(mx,mz,my)
      dimension  flm(mx,my)
      dimension  gam(mz), fwu(mz), fvw(mz)
c
      dimension  uu(mx,mz,my), vv(mx,mz,my), ww(mx,mz,my)
      dimension  uv(mx,mz,my), vw(mx,mz,my), wu(mx,mz,my)
      dimension  dif(mx,mz,my)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
      namelist  /les3/  xbub,  ybub,  zbub,   xbr,   ybr,   zbr,  tbub,
     :                  reye
c
      namelist  /post/ r_num, irec, iplane, jplane, kplane
c
      r_num    = ''
      irec     = 1
      iplane   = 0
      jplane   = 1
      kplane   = 0
c
      read (5,nml=post)
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
      read (10,nml=les3)
c
      close(10)
c
c ***
      fst = 0.0
      fsc = 0.0
      fc  = 0.0
      if ( rlat .le. 90.0 ) then
        fst = 2.0*7.292e-5*sin( rlat*3.141593/180.0 )
cx      fc  = 2.0*7.292e-5*cos( rlat*3.141593/180.0 )
      end if
c ***
c
      do k = 1,lz
        gam(k) = 1.0
        fwu(k) = 0.0
        fvw(k) = 0.0
      end do
c
      do m = 1,mip
        mt = m +20
c
        call sub_data_open ( r_num,f_name(m), mt, lx,lz,ly )
c
        select case ( f_name(m) )
          case ( 'u___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, u   )
          case ( 'v___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, v   )
          case ( 'w___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, w   )
          case ( 't___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, t   )
          case ( 'q___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, q   )
          case ( 'fm__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, fm  )
          case ( 'ql__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, ql  )
          case ( 'flm_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flm )
          case ( 'gam_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, gam )
          case ( 'fwu_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, fwu )
          case ( 'fvw_' )
            call sub_data_input ( mt,irec, mz, 1, 1, lz, 1, 1, fvw )
        end select
      end do
c
      ih   = jmin +nint(min(nstot-nstep+jout*irec,nstot)*dt)/60
      ih   = ih/60*100 +mod(ih,60)
      xp   = dx*( nx-2 )
      yp   = dy*( jplane-1.5 )
      zp   = dz*( nz   )
c
      write(6,'(i5.4)') ih
      write(6,*) real(dx), real(dy), real(dz)
      write(6,*) real(xp), real(yp), real(zp)
      write(6,*) 'x-z'
c
        call sub_vor (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w,
     o                  uu, vv, ww )
        call sub_strtil_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, fst, fc,
     i                  v, uu, vv, ww,
     o                  uv, vw, wu, dif )
c
      do k = 2,nz
      do i = 1,nx
        ave = uv(i,k,jplane)
        write(6,*) 'Sy', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
      do k = 2,nz
      do i = 1,nx
        ave = vw(i,k,jplane)
        write(6,*) 'TXy', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
      do k = 2,nz
      do i = 1,nx
        ave = wu(i,k,jplane)
        write(6,*) 'TZy', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
        call sub_verttp_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  w, vv,
     o                  uv, wu )
c
      do k = 2,nz
      do i = 1,nx
        ave = uv(i,k,jplane)
        write(6,*) 'Ty', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
        call sub_barocli_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref, psf,
     i                  t, q, ql,
     o                  uv, wu )
c
      do k = 2,nz
      do i = 1,nx
        ave = uv(i,k,jplane)
        write(6,*) 'By', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
        call sub_vordif_y ( one,
     i                  mx, mz, nx, nz, ny, dx, dz, dy,
     i                  u, v, w, fm, gam, fwu, fvw, flm,
     w                  uu, vv, ww, uv, vw, wu,
     o                  dif )
c
      do k = 2,nz
      do i = 1,nx
        ave = dif(i,k,jplane)
        write(6,*) 'Dy', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
      if ( fsc .eq. 0.0 .and. reye .eq. 0.0 ) stop
c
        call sub_tilccf_y (
     i                  mx, mz, nx, nz, ny, dx, dz, dy, fsc, reye,
     i                  v,
     o                  uv, wu )
c
      do k = 2,nz
      do i = 1,nx
        ave = uv(i,k,jplane)
        write(6,*) 'Cy', real(dx*(i-2.0)), real(dz*(k-1.0)), real(ave)
      end do
      end do
c
  999 stop
      end
