c **********************************************************************
c *   Calculates zi from temporaly averaged buoyancy flux              *
c *                                                                    *
c *   Input parameters:                                                *
c *     r_num         : Run number                      (Run.Restart)  *
c *                   : For example, 01.01                             *
c *                                                                    *
c *                                   Apr/2011  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include  "sub_bc.f"
      include  "sub_flux_v.f"
      include  "sub_ziwst.f"
      include  "sub_data_seq.f"
c
      include  "../src/Implicit.h"
c
      parameter ( mx=502, my=502, mz=201 )
      parameter ( mip=12, one=1.0, zero=0.0 )
c
      character (len=5) :: r_num
      character (len=4) :: f_name(mip) =
     3                 (/'u___', 'v___', 'w___', 't___', 'q___',
     3                   'fh__',
     3                   'ql__', 'vt__', 'vq__',
     2                   'flm_', 'flt_', 'flq_'                /)
c
      dimension  u (mx,mz,my), v (mx,mz,my), w (mx,mz,my)
      dimension  t (mx,mz,my), q (mx,mz,my)
      dimension  fh(mx,mz,my)
      dimension  ql(mx,mz,my), vt(mx,mz,my), vq(mx,mz,my)
      dimension  flm(mx,my), flt(mx,my), flq(mx,my)
c
      dimension  tav(mz)
      dimension  uu(mx,mz,my), vv(mx,mz,my), ww(mx,mz,my)
      dimension  uv(mx,mz,my)
c
      dimension  uav(mx,mz,my), vav(mx,mz,my), wav(mx,mz,my)
      dimension  fav(mx,my)
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      r_num    = ''
c
      write(6,'(a,$)') 'Specify a run number (xx.xx) =? '
      read (5,'(a)')   r_num
      write(6,'(a,$)') 'Specify start and end record numbers =? '
      read (5,*)       irst, ired
c
      open (10,file='para'//r_num,status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
c
      close(10)
c
      do m = 1,mip
        mt = m +20
c
        call sub_data_open ( r_num,f_name(m), mt, lx,lz,ly )
      end do
c
      recsum = 0.0
c
      do krec = irst,ired
          irec = krec
        do m = 1,mip
          mt = m +20
c
        select case ( f_name(m) )
          case ( 'u___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, u   )
          case ( 'v___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, v   )
          case ( 'w___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, w   )
          case ( 't___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, t   )
          case ( 'q___' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, q   )
          case ( 'fh__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, fh  )
          case ( 'ql__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, ql  )
          case ( 'vt__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, vt  )
          case ( 'vq__' )
            call sub_data_input ( mt,irec, mx,mz,my, lx,lz,ly, vq  )
          case ( 'flm_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flm )
          case ( 'flt_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flt )
          case ( 'flq_' )
            call sub_data_input ( mt,irec, mx,my, 1, lx,ly, 1, flq )
        end select
c
        if ( irec .eq. 999 ) goto 999
        end do
c
        write(6,*) 'krec =', krec
c
        call sub_flux_v ( one,
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref, psf,
     i                  u, v, w, t, q, ql, fh, vt, vq, flt, flq,
     w                  uav, vav, tav,
     o                  uu, vv, ww, uv )
c
        recsum = recsum +1.0
c
        do j = 1,ny
        do i = 1,nx
          fav(i,j)   = fav(i,j)   +flm(i,j)
        do k = 1,nz
          uav(i,k,j) = uav(i,k,j) +u  (i,k,j)
          vav(i,k,j) = vav(i,k,j) +v  (i,k,j)
          wav(i,k,j) = wav(i,k,j) +ww (i,k,j)
        end do
        end do
        end do
      end do
c
  999 continue
c
        do j = 1,ny
        do i = 1,nx
          fav(i,j)   = fav(i,j)   / recsum
        do k = 1,nz
          uav(i,k,j) = uav(i,k,j) / recsum
          vav(i,k,j) = vav(i,k,j) / recsum
          wav(i,k,j) = wav(i,k,j) / recsum
        end do
        end do
        end do
c
        call sub_ziwst ( zero,
     i                  mx, mz, nx, nz, ny, dx, dz, dy, tref,
     i                  uav, vav, wav, fav,
     w                  tav,
     o                  zi, wst, ust )
c
      write(6,*) 'zi',  real(zi)
      write(6,*) 'wst', real(wst)
      write(6,*) 'ust', real(ust)
c
      stop
      end
