c **********************************************************************
c *   Addition of fluctuations to flow fields below the nflay-th layer *
c *                                                                    *
c *   Input variables:                                                 *
c *     isfc          : < 0,       for sub.surface_stress_free         *
c *     nflay         : Number of layers to which fluctuations are     *
c *                   : added (Normally about nz/3)                    *
c *     frate         : Rate of fluctuation intensity to the geo-      *
c *                   : strophic wind (Normally about 5-6%)            *
c *     ugsf, vgsf    : Geostrophic wind                        (m/s)  *
c **********************************************************************
c
      subroutine  add_fluctuation ( isfc, nflay, frate, ugsf, vgsf )
c
      include  "Declare.h"
c
      rsum = 1.0/dble((nx-2)*(ny-2))
c
      if ( isfc .ge. 0 ) then
        kst = 1
        ked = min( nflay, nz/2 )
        zor = 0.0
      else
        ked = min( (nz+nflay)/2, nz )
        kst = nz -ked +1
        zor = 0.5*nz
      end if
c
      rt3  = 1.732051
      sigm = frate*max( sqrt( ugsf**2+vgsf**2 ), 1.0 )
c
      do k = kst,ked
        m   = k +1
        iu  = k
        iv  = k +ked
        iw  = k +ked*2
        it  = k +ked*3
        iq  = k +ked*4
        uav = 0.0
        vav = 0.0
        wav = 0.0
        tav = 0.0
        qav = 0.0
c
        fc1 = 1.0 -abs( k-0.5-zor )/( ked-zor )
        fc2 = 1.0 -abs( m-1.0-zor )/( ked-zor )
c
      do j = 2,ny-1
      do i = 2,nx-1
        tk(i,k,j) =           (fc1*sigm)**2
c
        urnd = fc1*sigm * rt3*urand( iu )
        vrnd = fc1*sigm * rt3*urand( iv )
cx      wrnd = fc2*sigm * rt3*urand( iw )
c?      trnd = fc1*5.e-2* rt3*urand( it )
c?      qrnd = fc1*5.e-6* rt3*urand( iq )
c
        uav       = uav       +urnd
        u (i,k,j) = u (i,k,j) +urnd
        vav       = vav       +vrnd
        v (i,k,j) = v (i,k,j) +vrnd
cx      wav       = wav       +wrnd
cx      w (i,m,j) = w (i,m,j) +wrnd
c
c?      tav       = tav       +trnd
c?      t (i,k,j) = t (i,k,j) +trnd
c?      qav       = qav       +qrnd
c?      q (i,k,j) = q (i,k,j) +qrnd
      end do
      end do
c
      do j = 2,ny-1
      do i = 2,nx-1
        u (i,k,j) = u (i,k,j) -uav*rsum
        v (i,k,j) = v (i,k,j) -vav*rsum
cx      w (i,k,j) = w (i,k,j) -wav*rsum
c?      t (i,k,j) = t (i,k,j) -tav*rsum
c?      q (i,k,j) = q (i,k,j) -qav*rsum
      end do
      end do
      end do
c
      call bc_lat_moment
cx    call bc_lat_scalar ( tk )
c
c?    call bc_lat_scalar ( t  )
c?    call bc_lat_scalar ( q  )
c
      call poisson
c
      do j = 1,ny
      do k = 1,mz
      do i = 1,mx
        pd(i,k,j) = 0.0
      end do
      end do
      end do
c
      return
      end
c
      function  urand ( ix )
c
      integer*8  ia, ib, im
c
      ia  =      32771
      ib  = 1234567891
      im  = 2147483648.5d0
c
      ix  = mod( ia*ix + ib, im )
c
      urand = 2.0d0*( dble(ix)/dble(im)-0.5d0 )
c
      return
      end
