c **********************************************************************
c *   Addition of fluctuations to flow fields below the nflay-th layer *
c *                                                                    *
c *   Input variables:                                                 *
c *     isfc          : < 0,       for sub.surface_stress_free         *
c *     nflay         : Number of layers to which fluctuations are     *
c *                   : added (Normally about nz/3)                    *
c *     frate         : Rate of fluctuation intensity to the geo-      *
c *                   : strophic wind (Normally about 5-6%)            *
c *     ugsf, vgsf    : Geostrophic wind                        (m/s)  *
c **********************************************************************
c
      subroutine  add_fluctuation ( isfc, nflay, frate, ugsf, vgsf )
c
      include  "Declare.h"
c
      integer*8  iu, iv, iw, it, iq
c
      if ( isfc .ge. 0 ) then
        kst = 1
        ked = min( nflay, nz/2 )
        zor = 0.0
      else
        ked = min( (nz+nflay)/2, nz )
        kst = nz -ked +1
        zor = 0.5*nz
      end if
c
      sigm = frate*max( sqrt( ugsf**2+vgsf**2 ), 1.0 )
c
      do k = kst,ked
        m   = k +1
        iu  = k
        iv  = k +ked
        iw  = k +ked*2
        it  = k +ked*3
        iq  = k +ked*4
        fc1 = 1.0 -abs( k-0.5-zor )/( ked-zor )
        fc2 = 1.0 -abs( m-1.0-zor )/( ked-zor )
c
      do j = 2,ny-1
      do i = 2,nx-1,2
        tk( i ,k,j) =             (fc1*sigm)**2
        tk(i+1,k,j) =             (fc1*sigm)**2
c
        call nrand ( iu, aa, bb )
        u ( i ,k,j) = u ( i ,k,j) +fc1*sigm * aa
        u (i+1,k,j) = u (i+1,k,j) +fc1*sigm * bb
        call nrand ( iv, aa, bb )
        v ( i ,k,j) = v ( i ,k,j) +fc1*sigm * aa
        v (i+1,k,j) = v (i+1,k,j) +fc1*sigm * bb
c
cx      call nrand ( iw, aa, bb )
cx      w ( i ,m,j) = w ( i ,m,j) +fc2*sigm * aa
cx      w (i+1,m,j) = w (i+1,m,j) +fc2*sigm * bb
c
c?      call nrand ( it, aa, bb )
c?      t ( i ,k,j) = t ( i ,k,j) +fc1*1.d-1* aa
c?      t (i+1,k,j) = t (i+1,k,j) +fc1*1.d-1* bb
c?      call nrand ( iq, aa, bb )
c?      q ( i ,k,j) = q ( i ,k,j) +fc1*1.d-5* aa
c?      q (i+1,k,j) = q (i+1,k,j) +fc1*1.d-5* bb
      end do
      end do
      end do
c
      call bc_lat_moment
cx    call bc_lat_scalar ( tk )
c
c?    call bc_lat_scalar ( t  )
c?    call bc_lat_scalar ( q  )
c
      call poisson
c
      do j = 1,ny
      do k = 1,mz
      do i = 1,mx
        pd(i,k,j) = 0.0
      end do
      end do
      end do
c
      return
      end
c
      subroutine  nrand ( ix, aa, bb )
c
      include  "Implicit.h"
c
      integer*8  ix
      integer*8  ia, ib, im
      double precision  x1, x2
c
      ia  =      32771
      ib  = 1234567891
      im  = 2147483648.5d0
c
      ix  = mod( ia*ix + ib, im )
      x1  = dble(ix+1)/dble(im)
      ix  = mod( ia*ix + ib, im )
      x2  = dble(ix+1)/dble(im)
c
      x1  = sqrt( -2.0d0*log(x1) )
      x2  = 6.28318530717959d0*x2
c
      aa  = x1*sin(x2)
      bb  = x1*cos(x2)
c
      return
      end
