c **********************************************************************
c *   A large-eddy simulation (LES) model for the Earth Simulator      *
c *                                                                    *
c *                                     Author: M. Nakanishi (N.D.A)   *
c *                                             naka@nda.ac.jp         *
c **********************************************************************
c
      include  "Declare.h"
      include  "IOfile.h"
c
      call arrangement (
     :                 nssta, nstot,  jout,  lout,
     :                  isgs,  isfc,  irad,  icon,  isca,
     :                  jsec,  rlat,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                  nspl,  nspu,   csp,
     :                  reye )
c
      fac1 = 1.0
      zero = 0.0
      pmx  = 0.0
      pmy  = 0.0
c
        aa  = 1.0
        new = 0
      if ( nssta .gt. 1 ) then
        aa  = 1.5
        new = 1
c
c  ***  Download of ust for the restart mode  ***
        ust = fub(1,nz+1,1)
      end if
c
      if ( irad .ne. 0 ) irad = 60.0/dt +0.5
c
c  ***********************  Simulation start  ***********************
      do istep = nssta,nstot
c
        jstep =  istep - nssta + 1
        chour = ( jsec + dt*(istep-1) )/3600.0
c
c  ***  Physical processes  ***
        if ( isfc .eq. 0 .or. irad .gt. 0
     :                   .or. icon .gt. 0 )
     :    call hydro_pressure
c
        if     ( icon              .gt. 0 )
     :    call condensation
        if     ( irad              .gt. 0 ) then
          if   ( mod(istep-1,irad) .eq. 0 )
     :    call radiation ( chour, rlat, elat, albd, clov, ulov )
        end if
c
        if     ( isfc              .eq. 0 ) then
          call surface_forecast  (
     :                new, z0m, z0h, tdeep, swet, crso, fkso,
     :                ust, duz )
        elseif ( isfc              .gt. 0 ) then
          call surface_prescript ( isfc, istep,
     :                new, z0m, z0h, tfmx, qfmx, phour, dhour, chour,
     :                ust, duz )
        else
          call surface_stress_free
        end if
c
          call sgs_model ( isgs, isfc, ust, duz, reye )
c
c  ***  Temperature, Humidity, and so on  ***
          call physical_term  ( 4 )
          call flux_scalar    ( t, fh, flt, fac1, tnu )
          call predict_scalar ( aa, t, ftb, gamt )
c
        if ( icon .ge. 0 ) then
          call physical_term  ( 5 )
          call flux_scalar    ( q, fh, flq, fac1, tnu )
          call predict_scalar ( aa, q, fqb, gamq )
        end if
c
        if ( isca .ne. 0 ) then
          call physical_term  ( 7 )
          call flux_scalar    ( sa, fh, fla, fac1, tnu )
          call predict_scalar ( aa, sa, fab, zero )
c
          call bc_lat_scalar  ( sa )
          call bc_upp_scalar  ( sa, zero )
        end if
c
c  ***  Momentum  ***
        call flux_moment
        call hydro_subtraction
        call predict_moment ( aa, pmx, pmy, reye )
c
        call sponge_layer   ( nspl, nspu, csp, icon )
        call poisson
c
        if ( mod(istep,lout) .eq. 0 ) call div_check ( istep, ust )
c
        if ( mod(jstep,jout) .eq. 0 .or. istep .eq. nstot ) then
c  ***  Upload of ust for the restart mode  ***
          fub(1,nz+1,1) = ust
c
          call data_output
        end if
c
        aa   = 1.5
        new  = 1
c
      end do
c  ******************************************************************
c
      stop
      end
c
      subroutine  div_check ( istep, ust )
c
      include  "Declare.h"
c
      dimension  uav(mz), vav(mz)
c
      divmax = 0.0
c
      do j = 2,ny-1
      do k = 1,nz
      do i = 2,nx-1
        div = ( u (i+1, k , j )-u (i,k,j) ) / dx
     :       +( v ( i , k ,j+1)-v (i,k,j) ) / dy
     :       +( w ( i ,k+1, j )-w (i,k,j) ) / dz
c
        if ( divmax .lt. abs(div) ) then
          divmax = abs(div)
          imax   = i
          jmax   = j
          kmax   = k
        end if
      end do
      end do
      end do
c
      write(6,*) 'istep,i,j,k,divmax=',istep,imax,jmax,kmax,divmax
c
      rsum = 1.0/dble((nx-2)*(ny-2))
      tke  = 0.0
c
      do k = 1,nz
        uavk = 0.0
        vavk = 0.0
      do j = 2,ny-1
      do i = 2,nx-1
        uavk = uavk +u (i,k,j)
        vavk = vavk +v (i,k,j)
      end do
      end do
        uav(k) = uavk * rsum
        vav(k) = vavk * rsum
      end do
c
      do j = 2,ny-1
      do k = 1,nz
      do i = 2,nx-1
        tke = tke +    ( u (i+1, k , j )+u (i,k,j)-2.0*uav(k) )**2
     :            +    ( v ( i , k ,j+1)+v (i,k,j)-2.0*vav(k) )**2
     :            +    ( w ( i ,k+1, j )+w (i,k,j) )**2
     :            +8.0*  tk( i , k , j )
      end do
      end do
      end do
c
      tke  = 0.125*tke*dz * rsum
c
      write(6,*) 'istep,tke,ust=',istep,tke,ust
c
      return
      end
