c **********************************************************************
c *   Poisson equation for pressure (solved with SMAC method)          *
c *                                                                    *
c *   # FFTW version 2 is used.                                        *
c **********************************************************************
c
      subroutine  poisson
c
      include  "Declare.h"
c
      parameter ( lx=(nx-2)/2+1, ly=ny-2 )
      integer*8         pfwd, pbwd
      double precision  wk1(nx-2,ly)
      double complex    wk2(lx,  ly)
c
      dimension  wno(mx,my)
!hpf$ distribute (*,block) :: wno, wk1, wk2
c
      data  new / 0 /
c
      save  new, wno, pfwd, pbwd
c
      nxe  = lx *2
      nye  = ly
      nx2  = nx -2
      ny2  = ny -2
      rsum = 1.0/dble(nx2*ny2)
c
      if ( new .ne. 0 ) goto 100
c
        new = 1
c
        call rfftw2d_f77_create_plan ( pfwd, nx-2, ny-2, -1, 0 )
        call rfftw2d_f77_create_plan ( pbwd, nx-2, ny-2,  1, 0 )
c
c  ***  wno is the square of the modified wavenumber (m^[-2])  ***
c  ***  according to the staggered grid arrangement.           ***
        nyh = nye/2 +1
c
        do j = 1,nyh
        do i = 1,nxe
          ix = ( i-1 ) / 2
          iy =   j-1
          xx = sin( 3.14159265358979d0*dble(ix)/dble(nx-2) ) / dx
          yy = sin( 3.14159265358979d0*dble(iy)/dble(ny-2) ) / dy
          wno(i,j) = 4.0*( xx**2 +yy**2 )
        end do
        end do
        do j = nyh+1,nye
        do i =     1,nxe
          wno(i,j) = wno(i,nye-j+2)
        end do
        end do
c
  100 continue
c
c  ***  Right-hand side term of the Poisson equation  ***
      do j = 2,ny-1
      do k = 1,nz
      do i = 2,nx-1
        uu(i,k,j) = -( u (i+1, k , j )-u (i,k,j) ) / dx
     :              -( v ( i , k ,j+1)-v (i,k,j) ) / dy
     :              -( w ( i ,k+1, j )-w (i,k,j) ) / dz
      end do
      end do
      end do
c
c  ***  Forward Fourier transform  ***
      do k = 1,nz
        do j = 1,ny2
        do i = 1,nx2
          wk1(i,j) = uu(i+1, k ,j+1)
        end do
        end do
c
        call rfftwnd_f77_one_real_to_complex ( pfwd, wk1, wk2 )
c
        do j = 1,ly
        do i = 1,lx
          uu(i*2-1,k,j) = dble( wk2(i,j) ) * rsum
          uu(i*2  ,k,j) = imag( wk2(i,j) ) * rsum
        end do
        end do
      end do
c
c  ***  The following can be omitted if c = 0.0 at k = 1. ***
cx    do j = 1,nye
cx    do i = 1,nxe
cx      vv(i,1,j) = 1.0
cx      ww(i,1,j) = 0.0
cx    end do
cx    end do
c
!hpf$ independent
      do j = 1,nye
      do k = 1,nz
        km1 = max( k-1, 1 )
                        a  = 1.0 / dz**2
                        c  = a
        if ( k .eq. 1 ) c  = 0.0
      do i = 1,nxe
        b  = a +c +wno(i,j)
        d  = uu(i,k,j)
c
        den       =   b -c*vv(i,km1,j)
        vv(i,k,j) =   a                  / den
        ww(i,k,j) = ( d +c*ww(i,km1,j) ) / den
      end do
      end do
      end do
c
c  ***  The following set the horizontal average of pd  ***
c  ***  at the top boundary to zero.                    ***
      vv(1,nz,1) = 0.0
      ww(1,nz,1) = 0.0
      vv(2,nz,1) = 0.0
      ww(2,nz,1) = 0.0
c
c  ***  Upper boundary condition  ***
      do j = 1,nye
      do i = 1,nxe
        uu(i,nz+1,j) = ww(i,nz,j)/( 1.0-vv(i,nz,j) )
      end do
      end do
c
      do j = 1,nye
      do k = nz,1,-1
      do i = 1,nxe
        uu(i,k,j) = vv(i,k,j)*uu(i,k+1,j) +ww(i,k,j)
      end do
      end do
      end do
c
c  ***  Backward Fourier transform  ***
      do k = 1,nz
        do j = 1,ly
        do i = 1,lx
          wk2(i,j) = dcmplx( uu(i*2-1,k,j), uu(i*2,k,j) )
        end do
        end do
c
        call rfftwnd_f77_one_complex_to_real ( pbwd, wk2, wk1 )
c
        do j = 1,ny2
        do i = 1,nx2
          uu(i+1, k ,j+1) = wk1(i,j)
        end do
        end do
      end do
c
      call bc_lat_scalar ( uu )
cx    call bc_upp_scalar ( uu, 0.0 )
c
c  ***  Correction of the pressure and wind vector  ***
      do j = 1,ny
      do k = 1,nz
      do i = 1,mx
        pd(i,k,j) = pd(i,k,j) +  uu(i,k,j) / dt
      end do
      end do
      end do
c
      do j = 2,ny-1
      do k = 1,nz
        m  = k +1
      do i = 2,nx-1
        u (i,k,j) = u (i,k,j) -( uu(i,k,j)-uu(i-1, k , j ) ) / dx
        v (i,k,j) = v (i,k,j) -( uu(i,k,j)-uu( i , k ,j-1) ) / dy
        w (i,m,j) = w (i,m,j) -( uu(i,m,j)-uu( i ,m-1, j ) ) / dz
      end do
      end do
      end do
c
      call bc_lat_moment
      call bc_upp_moment
c
      return
      end
