c **********************************************************************
c *   Converts binary format into Vis5d format                         *
c *                                                                    *
c *   Input parameters:                                                *
c *     f_name(s)     : File name               (Element_Run.Restart)  *
c *                   : For example, u___01.01                         *
c *     irecst        : First record number to be displayed            *
c *     ireced        : Last  record number to be displayed            *
c *     inc           : Increments for x and y grid numbers            *
c *     ival          : = 0,       raw values;                         *
c *                   : otherwise, fluctuations from horizontal ave    *
c *     ztop          : Height of top boundary to be displayed    (m)  *
c *     zbtm          : Height of bottom boundary to be displayed (m)  *
c *                                                                    *
c *                                   Dec/2009  M. Nakanishi (N.D.A)   *
c **********************************************************************
c
      include "/usr/local/vis5d-5.2/src/v5df.h"
c
      integer  n
      real     G(MAXROWS*MAXCOLUMNS*MAXLEVELS)
c
      character (len=10) :: varname(MAXVARS)
      integer  times(MAXTIMES)
      integer  dates(MAXTIMES)
      integer  numtimes
      integer  numvars
      integer  nr, nc, nl
      real     northlat
      real     latinc
      real     westlon
      real     loninc
      real     bottomhgt
      real     hgtinc
c
      parameter ( my=MAXROWS, mx=MAXCOLUMNS, mz=MAXLEVELS )
c * If you want to change these parameters, those in
c * /usr/local/vis5d-5.2/src/v5df.h are needed to be changed.
c
      character (len=9) :: f_name(MAXVARS)
      integer           ival(MAXVARS)
c
      double precision  dat(mx,my,mz), ave
c
      namelist  /les1/  nrun, nstep,  iout,  jout,  lout
      namelist  /les2/  isgs,  isfc,  irad,  icon,  isca,
     :                  jmin,  rlat,    dt,    dx,    dy,    dz,
     :                         ugsf,  vgsf,         aglw,  agmd,
     :                  gulw,  gvlw,  gumd,  gvmd,
     :                  tref,   tsf,   qsf,   psf,  hglw,  hgmd,
     :                  gtlw,  gqlw,  gtmd,  gqmd,  gamt,  gamq,
     :                   z0m,   z0h,  tfmx,  qfmx, phour, dhour,
     :                 tdeep,  swet,  crso,  fkso,
     :                  elat,  albd,  clov,  ulov,
     :                 nflay, frate,
     :                  nspl,  nspu,   csp, nstot
c
      namelist  /v5d/ f_name, irecst, ireced, inc, ival, ztop, zbtm
c
      f_name   = ''
      irecst   = 1
      ireced   = 1
      inc      = 1
      ival     = 0
      ztop     = 1.0e4
      zbtm     = 0.0
c
      read (5,nml=v5d)
c
      open (10,file='para'//f_name(1)(5:9),status='old',iostat=ios)
      if ( ios .ne. 0 ) stop 'para-file not found.'
c
      if ( ireced .lt. irecst ) ireced = irecst
c
      read (10,*) lx, lz, ly
      read (10,*) nx, nz, ny
c
      if ( lx .gt. mx .or. ly .gt. my .or. lz .gt. mz ) then
                        write(6,*) 'nx, ny, nz =', nx, ny, nz
                        stop 'Grid number is large!'
      end if
c
      read (10,nml=les1)
      read (10,nml=les2)
c
      close(10)
c
      do j = irecst,ireced
        ih = jmin +nint(min(nstot-nstep+jout*j,nstot)*dt)/60
        times(j-irecst+1) = ih/60*10000 +mod(ih,60)*100
        dates(j-irecst+1) = 1
      end do
      numtimes   = ireced -irecst +1
      nr         = ( (ny-2)-1 )/inc +1
      nc         = ( (nx-2)-1 )/inc +1
      nb         = max( min( nz, int(zbtm/dz)+1 ),      1 )
      nl         = max( min( nz, int(ztop/dz)   )-nb+1, 1 )
      northlat   = 35.0
      latinc     = dy/100000.0 * inc
      westlon    = 135.0
      loninc     = dx/100000.0 * inc
      hgtinc     = dz/1000.0
      bottomhgt  = hgtinc*( nb-0.5 )
c
      do mt = 1,MAXVARS
        open (mt+10,file=f_name(mt),form='unformatted',
     :           status='old',iostat=ios)
        if ( ios .ne. 0 ) exit
c
        varname(mt) = f_name(mt)(1:2)
        numvars     = mt
c
        do j = 1,irecst-1
          read (mt+10,end=999)
        end do
      end do
c
c     Create the v5d file.
      n = v5dcreatesimple( 'test.v5d', numtimes, numvars, nr, nc, nl,
     :                 varname, times, dates,
     :                 northlat, latinc, westlon, loninc,
     :                 bottomhgt, hgtinc )
      if ( n .eq. 0 ) then
         call exit( 1 )
      end if
c
      do mj = irecst,ireced
      do mt = 1,numvars
c
        read (mt+10,end=100) (((dat(i,j,k),i=1,lx),k=1,lz),j=1,ly)
c
        ax = 0.0
        ay = 0.0
        az = 0.0
        select case ( f_name(mt)(1:4) )
          case ( 'u___' ); ax = 0.5
          case ( 'v___' ); ay = 0.5
          case ( 'w___' ); az = 0.5
          case ( 'zx__' ); ay = 0.5; az = 0.5
          case ( 'zy__' ); az = 0.5; ax = 0.5
          case ( 'zz__' ); ax = 0.5; ay = 0.5
        end select
c
        if ( f_name(mt)(1:4) .ne. 'ql__' .and. ival(mt) .ne. 0 ) then
          do k = 1,nz
            ave = 0.0
            do j = 2,ny-1
            do i = 2,nx-1
              ave = ave +dat(i,j,k)
            end do
            end do
            ave = ave/dble((nx-2)*(ny-2))
c
            do j = 1,ny
            do i = 1,nx
              dat(i,j,k) = dat(i,j,k) -ave
            end do
            end do
          end do
        end if
c
c     Enter the conversion subroutine
        call convert( mj-irecst+1, mt, ax, ay, az, inc, dat, nb,
     :                nr, nc, nl, G )
c
      end do
      end do
c
  100 continue
c
c     Close the v5d file and exit
      n = v5dclose()
      if ( n .eq. 0 ) then
c        failed
         call exit( 1 )
      else
c        success
         call exit( 0 )
      endif
c
  999 stop
      end
c
c     Read 3-D grids from input file, write them to the output file.
c
      subroutine convert( itime, ivar, ax, ay, az, inc, dat, nb,
     :                    nr, nc, nl, G )
c
      include "/usr/local/vis5d-5.2/src/v5df.h"
c
      integer  nr
      integer  nc
      integer  nl
      real     G(nr, nc, nl)
c
      parameter ( my=MAXROWS, mx=MAXCOLUMNS, mz=MAXLEVELS )
      double precision  dat(mx,my,mz)
c
      bx = 1.0 -ax
      by = 1.0 -ay
      bz = 1.0 -az
c
      do k = 1,nl
      do j = 1,nc
      do i = 1,nr
        id =            1 +( (j-1)*inc+1 )
        jd = (nr-1)*inc+3 -( (i-1)*inc+1 )
        kd = k +nb -1
c
        G(i,j,k) = ax*ay*az * dat(id+1,jd+1,kd+1)
     :           + ax*ay*bz * dat(id+1,jd+1,kd  )
     :           + ax*by*az * dat(id+1,jd  ,kd+1)
     :           + ax*by*bz * dat(id+1,jd  ,kd  )
     :           + bx*ay*az * dat(id  ,jd+1,kd+1)
     :           + bx*ay*bz * dat(id  ,jd+1,kd  )
     :           + bx*by*az * dat(id  ,jd  ,kd+1)
     :           + bx*by*bz * dat(id  ,jd  ,kd  )
      end do
      end do
      end do
c
c     Write the 3-D grid to the v5d file
      n = v5dwrite( itime, ivar, G )
      if ( n .eq. 0 ) then
c        error
         call exit(1)
      end if
c
      return
      end
